//line php7/php7.y:2
package php7

import __yyfmt__ "fmt"

//line php7/php7.y:2
import (
	"strconv"
	"strings"

	"github.com/z7zmey/php-parser/freefloating"
	"github.com/z7zmey/php-parser/node"
	"github.com/z7zmey/php-parser/node/expr"
	"github.com/z7zmey/php-parser/node/expr/assign"
	"github.com/z7zmey/php-parser/node/expr/binary"
	"github.com/z7zmey/php-parser/node/expr/cast"
	"github.com/z7zmey/php-parser/node/name"
	"github.com/z7zmey/php-parser/node/scalar"
	"github.com/z7zmey/php-parser/node/stmt"
	"github.com/z7zmey/php-parser/scanner"
)

//line php7/php7.y:22
type yySymType struct {
	yys   int
	node  node.Node
	token *scanner.Token
	list  []node.Node
	str   string

	ClassExtends     *stmt.ClassExtends
	ClassImplements  *stmt.ClassImplements
	InterfaceExtends *stmt.InterfaceExtends
	ClosureUse       *expr.ClosureUse
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EXIT = 57348
const T_IF = 57349
const T_LNUMBER = 57350
const T_DNUMBER = 57351
const T_STRING = 57352
const T_STRING_VARNAME = 57353
const T_VARIABLE = 57354
const T_NUM_STRING = 57355
const T_INLINE_HTML = 57356
const T_CHARACTER = 57357
const T_BAD_CHARACTER = 57358
const T_ENCAPSED_AND_WHITESPACE = 57359
const T_CONSTANT_ENCAPSED_STRING = 57360
const T_ECHO = 57361
const T_DO = 57362
const T_WHILE = 57363
const T_ENDWHILE = 57364
const T_FOR = 57365
const T_ENDFOR = 57366
const T_FOREACH = 57367
const T_ENDFOREACH = 57368
const T_DECLARE = 57369
const T_ENDDECLARE = 57370
const T_AS = 57371
const T_SWITCH = 57372
const T_ENDSWITCH = 57373
const T_CASE = 57374
const T_DEFAULT = 57375
const T_BREAK = 57376
const T_CONTINUE = 57377
const T_GOTO = 57378
const T_FUNCTION = 57379
const T_FN = 57380
const T_CONST = 57381
const T_RETURN = 57382
const T_TRY = 57383
const T_CATCH = 57384
const T_FINALLY = 57385
const T_THROW = 57386
const T_USE = 57387
const T_INSTEADOF = 57388
const T_GLOBAL = 57389
const T_VAR = 57390
const T_UNSET = 57391
const T_ISSET = 57392
const T_EMPTY = 57393
const T_HALT_COMPILER = 57394
const T_CLASS = 57395
const T_TRAIT = 57396
const T_INTERFACE = 57397
const T_EXTENDS = 57398
const T_IMPLEMENTS = 57399
const T_OBJECT_OPERATOR = 57400
const T_DOUBLE_ARROW = 57401
const T_LIST = 57402
const T_ARRAY = 57403
const T_CALLABLE = 57404
const T_CLASS_C = 57405
const T_TRAIT_C = 57406
const T_METHOD_C = 57407
const T_FUNC_C = 57408
const T_LINE = 57409
const T_FILE = 57410
const T_COMMENT = 57411
const T_DOC_COMMENT = 57412
const T_OPEN_TAG = 57413
const T_OPEN_TAG_WITH_ECHO = 57414
const T_CLOSE_TAG = 57415
const T_WHITESPACE = 57416
const T_START_HEREDOC = 57417
const T_END_HEREDOC = 57418
const T_DOLLAR_OPEN_CURLY_BRACES = 57419
const T_CURLY_OPEN = 57420
const T_PAAMAYIM_NEKUDOTAYIM = 57421
const T_NAMESPACE = 57422
const T_NS_C = 57423
const T_DIR = 57424
const T_NS_SEPARATOR = 57425
const T_ELLIPSIS = 57426
const T_EVAL = 57427
const T_REQUIRE = 57428
const T_REQUIRE_ONCE = 57429
const T_LOGICAL_OR = 57430
const T_LOGICAL_XOR = 57431
const T_LOGICAL_AND = 57432
const T_INSTANCEOF = 57433
const T_NEW = 57434
const T_CLONE = 57435
const T_ELSEIF = 57436
const T_ELSE = 57437
const T_ENDIF = 57438
const T_PRINT = 57439
const T_YIELD = 57440
const T_STATIC = 57441
const T_ABSTRACT = 57442
const T_FINAL = 57443
const T_PRIVATE = 57444
const T_PROTECTED = 57445
const T_PUBLIC = 57446
const T_INC = 57447
const T_DEC = 57448
const T_YIELD_FROM = 57449
const T_INT_CAST = 57450
const T_DOUBLE_CAST = 57451
const T_STRING_CAST = 57452
const T_ARRAY_CAST = 57453
const T_OBJECT_CAST = 57454
const T_BOOL_CAST = 57455
const T_UNSET_CAST = 57456
const T_COALESCE = 57457
const T_SPACESHIP = 57458
const T_NOELSE = 57459
const T_PLUS_EQUAL = 57460
const T_MINUS_EQUAL = 57461
const T_MUL_EQUAL = 57462
const T_POW_EQUAL = 57463
const T_DIV_EQUAL = 57464
const T_CONCAT_EQUAL = 57465
const T_MOD_EQUAL = 57466
const T_AND_EQUAL = 57467
const T_OR_EQUAL = 57468
const T_XOR_EQUAL = 57469
const T_SL_EQUAL = 57470
const T_SR_EQUAL = 57471
const T_COALESCE_EQUAL = 57472
const T_BOOLEAN_OR = 57473
const T_BOOLEAN_AND = 57474
const T_POW = 57475
const T_SL = 57476
const T_SR = 57477
const T_IS_IDENTICAL = 57478
const T_IS_NOT_IDENTICAL = 57479
const T_IS_EQUAL = 57480
const T_IS_NOT_EQUAL = 57481
const T_IS_SMALLER_OR_EQUAL = 57482
const T_IS_GREATER_OR_EQUAL = 57483

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_FN",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_DOUBLE_ARROW",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_INSTANCEOF",
	"T_NEW",
	"T_CLONE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_PRINT",
	"T_YIELD",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_INC",
	"T_DEC",
	"T_YIELD_FROM",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"T_COALESCE",
	"T_SPACESHIP",
	"T_NOELSE",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_POW_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_COALESCE_EQUAL",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"T_POW",
	"T_SL",
	"T_SR",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_SMALLER_OR_EQUAL",
	"T_IS_GREATER_OR_EQUAL",
	"'\"'",
	"'`'",
	"'{'",
	"'}'",
	"';'",
	"':'",
	"'('",
	"')'",
	"'['",
	"']'",
	"'?'",
	"'&'",
	"'-'",
	"'+'",
	"'!'",
	"'~'",
	"'@'",
	"'$'",
	"','",
	"'|'",
	"'='",
	"'^'",
	"'*'",
	"'/'",
	"'%'",
	"'<'",
	"'>'",
	"'.'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line php7/php7.y:5616

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 2,
	1, 1,
	-2, 0,
	-1, 44,
	58, 422,
	79, 422,
	144, 422,
	150, 422,
	-2, 417,
	-1, 48,
	148, 425,
	-2, 434,
	-1, 84,
	58, 424,
	79, 424,
	144, 424,
	148, 427,
	150, 424,
	-2, 412,
	-1, 107,
	79, 385,
	-2, 414,
	-1, 229,
	58, 422,
	79, 422,
	144, 422,
	150, 422,
	-2, 313,
	-1, 232,
	148, 427,
	-2, 424,
	-1, 235,
	58, 422,
	79, 422,
	144, 422,
	150, 422,
	-2, 315,
	-1, 354,
	116, 0,
	136, 0,
	137, 0,
	138, 0,
	139, 0,
	-2, 337,
	-1, 355,
	116, 0,
	136, 0,
	137, 0,
	138, 0,
	139, 0,
	-2, 338,
	-1, 356,
	116, 0,
	136, 0,
	137, 0,
	138, 0,
	139, 0,
	-2, 339,
	-1, 357,
	116, 0,
	136, 0,
	137, 0,
	138, 0,
	139, 0,
	-2, 340,
	-1, 358,
	140, 0,
	141, 0,
	167, 0,
	168, 0,
	-2, 341,
	-1, 359,
	140, 0,
	141, 0,
	167, 0,
	168, 0,
	-2, 342,
	-1, 360,
	140, 0,
	141, 0,
	167, 0,
	168, 0,
	-2, 343,
	-1, 361,
	140, 0,
	141, 0,
	167, 0,
	168, 0,
	-2, 344,
	-1, 362,
	116, 0,
	136, 0,
	137, 0,
	138, 0,
	139, 0,
	-2, 345,
	-1, 369,
	149, 163,
	160, 163,
	-2, 422,
	-1, 413,
	149, 462,
	151, 462,
	160, 462,
	-2, 422,
	-1, 417,
	58, 423,
	79, 423,
	144, 423,
	148, 426,
	150, 423,
	-2, 347,
	-1, 431,
	148, 448,
	-2, 415,
	-1, 432,
	148, 450,
	-2, 440,
	-1, 511,
	148, 448,
	-2, 416,
	-1, 512,
	148, 450,
	-2, 441,
	-1, 571,
	149, 213,
	-2, 218,
	-1, 596,
	148, 426,
	-2, 423,
	-1, 648,
	149, 213,
	-2, 218,
	-1, 653,
	149, 183,
	-2, 422,
	-1, 661,
	149, 213,
	-2, 218,
	-1, 686,
	149, 461,
	151, 461,
	160, 461,
	-2, 422,
	-1, 719,
	149, 184,
	-2, 422,
	-1, 739,
	12, 265,
	-2, 268,
	-1, 753,
	94, 208,
	95, 208,
	96, 208,
	-2, 0,
	-1, 778,
	149, 183,
	-2, 422,
	-1, 780,
	149, 186,
	-2, 396,
	-1, 800,
	94, 209,
	95, 209,
	96, 209,
	-2, 0,
	-1, 849,
	31, 199,
	32, 199,
	33, 199,
	145, 199,
	-2, 0,
	-1, 882,
	29, 76,
	-2, 80,
	-1, 885,
	31, 198,
	32, 198,
	33, 198,
	145, 198,
	-2, 0,
	-1, 914,
	149, 213,
	-2, 218,
}

const yyPrivate = 57344

const yyLast = 7732

var yyAct = [...]int{

	28, 130, 825, 838, 662, 861, 376, 578, 741, 436,
	874, 107, 837, 793, 774, 666, 811, 675, 785, 126,
	652, 633, 138, 138, 138, 664, 221, 151, 711, 565,
	700, 313, 667, 322, 5, 186, 532, 632, 368, 573,
	405, 514, 522, 80, 223, 317, 150, 378, 9, 316,
	132, 189, 8, 225, 228, 128, 143, 236, 237, 238,
	239, 240, 147, 2, 241, 242, 243, 244, 245, 246,
	247, 127, 250, 125, 513, 258, 259, 260, 315, 314,
	137, 7, 6, 430, 264, 870, 864, 684, 854, 273,
	274, 835, 276, 277, 214, 215, 590, 269, 230, 230,
	82, 334, 309, 140, 141, 677, 759, 202, 203, 204,
	205, 206, 207, 208, 209, 210, 211, 212, 213, 254,
	406, 111, 105, 842, 892, 841, 868, 105, 704, 832,
	541, 335, 319, 115, 121, 893, 324, 325, 84, 677,
	869, 44, 306, 833, 302, 336, 728, 626, 621, 285,
	287, 201, 105, 566, 337, 338, 339, 340, 341, 342,
	343, 344, 345, 346, 347, 348, 349, 350, 351, 352,
	353, 354, 355, 356, 357, 358, 359, 360, 361, 362,
	295, 364, 366, 556, 370, 321, 266, 372, 411, 568,
	117, 269, 105, 232, 232, 862, 229, 235, 333, 79,
	308, 380, 388, 390, 391, 392, 393, 394, 395, 396,
	397, 398, 399, 400, 401, 190, 331, 402, 138, 404,
	117, 225, 105, 261, 144, 730, 230, 424, 329, 384,
	332, 307, 415, 268, 290, 225, 292, 855, 301, 179,
	780, 299, 330, 926, 305, 308, 693, 409, 689, 610,
	138, 597, 302, 585, 407, 410, 371, 425, 179, 283,
	134, 416, 138, 112, 363, 518, 431, 511, 888, 106,
	230, 820, 523, 524, 106, 819, 525, 809, 801, 233,
	266, 165, 168, 169, 529, 270, 519, 533, 784, 225,
	134, 606, 600, 112, 603, 601, 607, 117, 403, 106,
	165, 230, 163, 162, 773, 727, 284, 717, 698, 233,
	551, 219, 164, 166, 167, 535, 914, 161, 828, 423,
	306, 232, 696, 688, 369, 650, 638, 5, 628, 782,
	418, 164, 166, 167, 598, 561, 863, 151, 589, 106,
	560, 9, 429, 520, 291, 8, 720, 510, 669, 670,
	687, 517, 661, 117, 648, 105, 286, 516, 538, 813,
	812, 110, 571, 554, 550, 232, 564, 134, 413, 106,
	112, 552, 420, 421, 7, 6, 544, 646, 414, 270,
	647, 826, 570, 562, 580, 385, 581, 558, 577, 582,
	583, 575, 383, 288, 579, 559, 232, 218, 420, 427,
	421, 421, 420, 217, 109, 289, 275, 272, 588, 271,
	249, 220, 225, 592, 216, 225, 184, 183, 182, 408,
	136, 135, 543, 134, 546, 572, 112, 131, 113, 609,
	155, 157, 156, 179, 612, 930, 602, 929, 920, 668,
	751, 595, 233, 387, 188, 903, 902, 587, 887, 850,
	821, 815, 808, 768, 769, 765, 591, 181, 178, 179,
	752, 716, 432, 512, 714, 712, 294, 710, 293, 707,
	555, 540, 611, 153, 154, 165, 168, 169, 170, 171,
	172, 173, 175, 177, 537, 768, 769, 386, 813, 812,
	374, 231, 328, 234, 180, 159, 163, 162, 327, 179,
	326, 165, 106, 158, 296, 160, 164, 166, 167, 174,
	176, 161, 844, 165, 807, 804, 802, 138, 616, 761,
	117, 608, 163, 162, 178, 909, 886, 859, 857, 803,
	144, 536, 164, 166, 167, 627, 536, 161, 536, 790,
	783, 165, 168, 169, 170, 171, 172, 173, 175, 177,
	733, 620, 613, 536, 676, 642, 324, 644, 637, 617,
	576, 625, 163, 162, 649, 306, 814, 634, 619, 185,
	5, 179, 164, 166, 167, 174, 176, 161, 419, 120,
	673, 179, 674, 671, 9, 640, 579, 789, 8, 643,
	906, 685, 253, 114, 191, 196, 197, 615, 767, 114,
	658, 198, 200, 199, 117, 651, 289, 718, 691, 515,
	230, 230, 672, 165, 168, 169, 681, 7, 6, 263,
	175, 177, 523, 165, 304, 255, 262, 533, 304, 574,
	422, 123, 379, 124, 163, 162, 382, 230, 304, 117,
	117, 77, 78, 708, 164, 166, 167, 174, 176, 161,
	701, 904, 786, 715, 116, 705, 634, 225, 117, 695,
	671, 722, 703, 699, 697, 702, 726, 546, 46, 546,
	636, 304, 630, 671, 706, 304, 713, 122, 289, 732,
	671, 146, 631, 721, 753, 754, 117, 547, 225, 749,
	256, 257, 549, 690, 748, 255, 280, 281, 230, 298,
	422, 731, 757, 724, 725, 232, 232, 192, 369, 653,
	750, 324, 545, 300, 755, 614, 255, 738, 408, 618,
	740, 225, 701, 905, 634, 542, 762, 320, 134, 303,
	758, 112, 232, 760, 255, 686, 763, 669, 670, 777,
	671, 770, 894, 772, 766, 148, 797, 779, 798, 775,
	579, 791, 546, 800, 787, 528, 134, 546, 546, 112,
	256, 257, 230, 745, 746, 747, 744, 743, 742, 810,
	146, 745, 746, 747, 744, 743, 742, 794, 818, 805,
	526, 256, 257, 829, 796, 824, 795, 148, 827, 117,
	806, 117, 817, 232, 823, 604, 719, 129, 255, 256,
	257, 834, 117, 422, 105, 816, 768, 769, 830, 635,
	110, 548, 1, 849, 255, 536, 123, 883, 124, 282,
	851, 843, 119, 377, 546, 375, 546, 848, 255, 195,
	255, 194, 193, 278, 853, 252, 867, 187, 671, 38,
	739, 846, 858, 871, 736, 737, 880, 866, 839, 884,
	885, 775, 655, 109, 879, 663, 531, 232, 222, 890,
	778, 891, 527, 256, 257, 895, 521, 889, 771, 768,
	769, 898, 134, 860, 896, 112, 367, 880, 899, 256,
	257, 546, 897, 873, 901, 879, 145, 792, 908, 142,
	323, 233, 279, 256, 257, 256, 257, 149, 836, 912,
	660, 822, 251, 381, 639, 913, 845, 928, 645, 840,
	919, 922, 915, 224, 918, 917, 579, 43, 42, 923,
	16, 15, 924, 599, 267, 49, 671, 48, 108, 927,
	50, 4, 931, 88, 89, 70, 47, 93, 94, 36,
	231, 105, 656, 27, 83, 654, 81, 110, 26, 18,
	17, 106, 19, 72, 30, 248, 31, 62, 265, 20,
	61, 878, 877, 21, 22, 35, 37, 876, 13, 23,
	33, 875, 735, 34, 12, 45, 24, 665, 29, 86,
	87, 10, 39, 40, 41, 723, 657, 310, 118, 51,
	109, 297, 102, 98, 99, 100, 95, 96, 738, 3,
	435, 740, 788, 729, 103, 0, 0, 0, 0, 11,
	101, 97, 112, 0, 90, 91, 92, 0, 0, 0,
	0, 85, 53, 0, 0, 0, 74, 75, 25, 77,
	78, 0, 0, 0, 54, 55, 76, 63, 64, 65,
	66, 67, 68, 69, 0, 0, 0, 0, 0, 0,
	0, 0, 745, 746, 747, 744, 743, 742, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 104, 73, 14, 629, 32, 0, 60, 0, 52,
	0, 0, 0, 57, 56, 58, 59, 71, 106, 4,
	0, 88, 89, 70, 47, 93, 94, 36, 865, 105,
	0, 27, 0, 0, 0, 110, 26, 18, 17, 0,
	19, 0, 30, 0, 31, 0, 0, 20, 0, 0,
	0, 21, 22, 35, 37, 0, 13, 23, 33, 0,
	0, 34, 12, 0, 24, 0, 29, 86, 87, 10,
	39, 40, 41, 0, 0, 0, 0, 51, 109, 0,
	102, 98, 99, 100, 95, 96, 738, 0, 0, 740,
	0, 0, 103, 0, 0, 0, 0, 11, 101, 97,
	112, 0, 90, 91, 92, 0, 0, 0, 0, 85,
	53, 0, 0, 0, 74, 75, 25, 77, 78, 0,
	0, 0, 54, 55, 76, 63, 64, 65, 66, 67,
	68, 69, 0, 0, 0, 0, 0, 0, 0, 0,
	745, 746, 747, 744, 743, 742, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 104,
	73, 14, 539, 32, 0, 60, 0, 52, 0, 0,
	0, 57, 56, 58, 59, 71, 106, 4, 0, 88,
	89, 70, 47, 93, 94, 36, 831, 105, 0, 27,
	0, 0, 0, 110, 26, 18, 17, 0, 19, 0,
	30, 0, 31, 0, 0, 20, 0, 0, 0, 21,
	22, 35, 37, 0, 13, 23, 33, 0, 0, 34,
	12, 0, 24, 0, 29, 86, 87, 10, 39, 40,
	41, 0, 0, 0, 0, 51, 109, 0, 102, 98,
	99, 100, 95, 96, 738, 0, 0, 740, 0, 0,
	103, 0, 0, 0, 0, 11, 101, 97, 112, 0,
	90, 91, 92, 0, 0, 0, 0, 85, 53, 0,
	0, 0, 74, 75, 25, 77, 78, 0, 0, 0,
	54, 55, 76, 63, 64, 65, 66, 67, 68, 69,
	0, 0, 0, 0, 0, 0, 0, 0, 745, 746,
	747, 744, 743, 742, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 104, 73, 14,
	0, 32, 0, 60, 0, 52, 0, 0, 0, 57,
	56, 58, 59, 71, 106, 312, 0, 88, 89, 70,
	47, 93, 94, 36, 799, 105, 0, 27, 0, 0,
	0, 110, 26, 18, 17, 0, 19, 0, 30, 0,
	31, 0, 0, 20, 0, 0, 0, 21, 22, 35,
	37, 0, 0, 23, 33, 0, 0, 34, 0, 0,
	24, 0, 29, 86, 87, 318, 39, 40, 41, 0,
	0, 0, 0, 51, 109, 0, 102, 98, 99, 100,
	95, 96, 738, 0, 0, 740, 0, 0, 103, 0,
	0, 0, 0, 134, 101, 97, 112, 0, 90, 91,
	92, 0, 0, 0, 0, 85, 53, 0, 0, 0,
	74, 75, 25, 77, 78, 0, 0, 0, 54, 55,
	76, 63, 64, 65, 66, 67, 68, 69, 0, 0,
	0, 0, 0, 0, 0, 0, 745, 746, 747, 744,
	743, 742, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 104, 73, 14, 932, 32,
	0, 60, 0, 52, 0, 0, 0, 57, 56, 58,
	59, 71, 106, 312, 0, 88, 89, 70, 47, 93,
	94, 36, 734, 105, 0, 27, 0, 0, 0, 110,
	26, 18, 17, 0, 19, 0, 30, 0, 31, 0,
	0, 20, 0, 0, 0, 21, 22, 35, 37, 0,
	0, 23, 33, 0, 0, 34, 0, 0, 24, 0,
	29, 86, 87, 318, 39, 40, 41, 0, 0, 0,
	0, 51, 109, 0, 102, 98, 99, 100, 95, 96,
	0, 0, 0, 0, 0, 0, 103, 0, 0, 0,
	0, 134, 101, 97, 112, 0, 90, 91, 92, 0,
	0, 0, 0, 85, 53, 0, 0, 0, 74, 75,
	25, 77, 78, 0, 0, 0, 54, 55, 76, 63,
	64, 65, 66, 67, 68, 69, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 104, 73, 14, 925, 32, 0, 60,
	0, 52, 0, 0, 0, 57, 56, 58, 59, 71,
	106, 312, 0, 88, 89, 70, 47, 93, 94, 36,
	0, 105, 0, 27, 0, 0, 0, 110, 26, 18,
	17, 0, 19, 0, 30, 0, 31, 0, 0, 20,
	0, 0, 0, 21, 22, 35, 37, 0, 0, 23,
	33, 0, 0, 34, 0, 0, 24, 0, 29, 86,
	87, 318, 39, 40, 41, 0, 0, 0, 0, 51,
	109, 0, 102, 98, 99, 100, 95, 96, 0, 0,
	0, 0, 0, 0, 103, 0, 0, 0, 0, 134,
	101, 97, 112, 0, 90, 91, 92, 0, 0, 0,
	0, 85, 53, 0, 0, 0, 74, 75, 25, 77,
	78, 0, 0, 0, 54, 55, 76, 63, 64, 65,
	66, 67, 68, 69, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 104, 73, 14, 921, 32, 0, 60, 0, 52,
	0, 0, 0, 57, 56, 58, 59, 71, 106, 312,
	0, 88, 89, 70, 47, 93, 94, 36, 0, 105,
	0, 27, 0, 0, 0, 110, 26, 18, 17, 0,
	19, 0, 30, 0, 31, 0, 0, 20, 0, 0,
	0, 21, 22, 35, 37, 0, 0, 23, 33, 0,
	0, 34, 0, 0, 24, 0, 29, 86, 87, 318,
	39, 40, 41, 0, 0, 0, 0, 51, 109, 0,
	102, 98, 99, 100, 95, 96, 0, 0, 0, 0,
	0, 0, 103, 0, 0, 0, 0, 134, 101, 97,
	112, 0, 90, 91, 92, 0, 0, 0, 0, 85,
	53, 0, 0, 0, 74, 75, 25, 77, 78, 0,
	0, 0, 54, 55, 76, 63, 64, 65, 66, 67,
	68, 69, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 104,
	73, 14, 911, 32, 0, 60, 0, 52, 0, 0,
	0, 57, 56, 58, 59, 71, 106, 312, 0, 88,
	89, 70, 47, 93, 94, 36, 0, 105, 0, 27,
	0, 0, 0, 110, 26, 18, 17, 0, 19, 0,
	30, 0, 31, 0, 0, 20, 0, 0, 0, 21,
	22, 35, 37, 0, 0, 23, 33, 0, 0, 34,
	0, 0, 24, 0, 29, 86, 87, 318, 39, 40,
	41, 0, 0, 0, 0, 51, 109, 0, 102, 98,
	99, 100, 95, 96, 0, 0, 0, 0, 0, 0,
	103, 0, 0, 0, 0, 134, 101, 97, 112, 0,
	90, 91, 92, 0, 0, 0, 0, 85, 53, 0,
	0, 0, 74, 75, 25, 77, 78, 0, 0, 0,
	54, 55, 76, 63, 64, 65, 66, 67, 68, 69,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 104, 73, 14,
	910, 32, 0, 60, 0, 52, 0, 0, 0, 57,
	56, 58, 59, 71, 106, 312, 0, 88, 89, 70,
	47, 93, 94, 36, 0, 105, 0, 27, 0, 0,
	0, 110, 26, 18, 17, 0, 19, 907, 30, 0,
	31, 0, 0, 20, 0, 0, 0, 21, 22, 35,
	37, 0, 0, 23, 33, 0, 0, 34, 0, 0,
	24, 0, 29, 86, 87, 318, 39, 40, 41, 0,
	0, 0, 0, 51, 109, 0, 102, 98, 99, 100,
	95, 96, 0, 0, 0, 0, 0, 0, 103, 0,
	0, 0, 0, 134, 101, 97, 112, 0, 90, 91,
	92, 0, 0, 0, 0, 85, 53, 0, 0, 0,
	74, 75, 25, 77, 78, 0, 0, 0, 54, 55,
	76, 63, 64, 65, 66, 67, 68, 69, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 104, 73, 14, 0, 32,
	0, 60, 0, 52, 0, 0, 0, 57, 56, 58,
	59, 71, 106, 312, 0, 88, 89, 70, 47, 93,
	94, 36, 0, 105, 0, 27, 0, 0, 0, 110,
	26, 18, 17, 0, 19, 0, 30, 0, 31, 0,
	0, 20, 0, 0, 0, 21, 22, 35, 37, 0,
	0, 23, 33, 0, 0, 34, 0, 0, 24, 0,
	29, 86, 87, 318, 39, 40, 41, 0, 0, 0,
	0, 51, 109, 0, 102, 98, 99, 100, 95, 96,
	0, 0, 0, 0, 0, 0, 103, 0, 0, 0,
	0, 134, 101, 97, 112, 0, 90, 91, 92, 0,
	0, 0, 0, 85, 53, 0, 0, 0, 74, 75,
	25, 77, 78, 0, 0, 0, 54, 55, 76, 63,
	64, 65, 66, 67, 68, 69, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 104, 73, 14, 856, 32, 0, 60,
	0, 52, 0, 0, 0, 57, 56, 58, 59, 71,
	106, 312, 0, 88, 89, 70, 47, 93, 94, 36,
	0, 105, 0, 27, 0, 0, 0, 110, 26, 18,
	17, 0, 19, 0, 30, 852, 31, 0, 0, 20,
	0, 0, 0, 21, 22, 35, 37, 0, 0, 23,
	33, 0, 0, 34, 0, 0, 24, 0, 29, 86,
	87, 318, 39, 40, 41, 0, 0, 0, 0, 51,
	109, 0, 102, 98, 99, 100, 95, 96, 0, 0,
	0, 0, 0, 0, 103, 0, 0, 0, 0, 134,
	101, 97, 112, 0, 90, 91, 92, 0, 0, 0,
	0, 85, 53, 0, 0, 0, 74, 75, 25, 77,
	78, 0, 0, 0, 54, 55, 76, 63, 64, 65,
	66, 67, 68, 69, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 104, 73, 14, 0, 32, 0, 60, 0, 52,
	0, 0, 0, 57, 56, 58, 59, 71, 106, 312,
	0, 88, 89, 70, 47, 93, 94, 36, 0, 105,
	0, 27, 0, 0, 0, 110, 26, 18, 17, 0,
	19, 0, 30, 0, 31, 781, 0, 20, 0, 0,
	0, 21, 22, 35, 37, 0, 0, 23, 33, 0,
	0, 34, 0, 0, 24, 0, 29, 86, 87, 318,
	39, 40, 41, 0, 0, 0, 0, 51, 109, 0,
	102, 98, 99, 100, 95, 96, 0, 0, 0, 0,
	0, 0, 103, 0, 0, 0, 0, 134, 101, 97,
	112, 0, 90, 91, 92, 0, 0, 0, 0, 85,
	53, 0, 0, 0, 74, 75, 25, 77, 78, 0,
	0, 0, 54, 55, 76, 63, 64, 65, 66, 67,
	68, 69, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 104,
	73, 14, 0, 32, 0, 60, 0, 52, 0, 0,
	0, 57, 56, 58, 59, 71, 106, 312, 0, 88,
	89, 70, 47, 93, 94, 36, 0, 105, 0, 27,
	0, 0, 0, 110, 26, 18, 17, 764, 19, 0,
	30, 0, 31, 0, 0, 20, 0, 0, 0, 21,
	22, 35, 37, 0, 0, 23, 33, 0, 0, 34,
	0, 0, 24, 0, 29, 86, 87, 318, 39, 40,
	41, 0, 0, 0, 0, 51, 109, 0, 102, 98,
	99, 100, 95, 96, 0, 0, 0, 0, 0, 0,
	103, 0, 0, 0, 0, 134, 101, 97, 112, 0,
	90, 91, 92, 0, 0, 0, 0, 85, 53, 0,
	0, 0, 74, 75, 25, 77, 78, 0, 0, 0,
	54, 55, 76, 63, 64, 65, 66, 67, 68, 69,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 104, 73, 14,
	0, 32, 0, 60, 0, 52, 0, 0, 0, 57,
	56, 58, 59, 71, 106, 312, 0, 88, 89, 70,
	47, 93, 94, 36, 0, 105, 0, 27, 0, 0,
	0, 110, 26, 18, 17, 0, 19, 0, 30, 0,
	31, 0, 0, 20, 0, 0, 0, 21, 22, 35,
	37, 0, 0, 23, 33, 0, 0, 34, 0, 0,
	24, 0, 29, 86, 87, 318, 39, 40, 41, 0,
	0, 0, 0, 51, 109, 0, 102, 98, 99, 100,
	95, 96, 0, 0, 0, 0, 0, 0, 103, 0,
	0, 0, 0, 134, 101, 97, 112, 0, 90, 91,
	92, 0, 0, 0, 0, 85, 53, 0, 0, 680,
	74, 75, 25, 77, 78, 0, 0, 0, 54, 55,
	76, 63, 64, 65, 66, 67, 68, 69, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 104, 73, 14, 0, 32,
	0, 60, 0, 52, 0, 0, 0, 57, 56, 58,
	59, 71, 106, 312, 0, 88, 89, 70, 47, 93,
	94, 36, 0, 105, 0, 27, 0, 0, 0, 110,
	26, 18, 17, 0, 19, 0, 30, 0, 31, 0,
	0, 20, 0, 0, 0, 21, 22, 35, 37, 0,
	0, 23, 33, 0, 0, 34, 0, 0, 24, 0,
	29, 86, 87, 318, 39, 40, 41, 0, 0, 0,
	0, 51, 109, 0, 102, 98, 99, 100, 95, 96,
	0, 0, 0, 0, 0, 0, 103, 0, 0, 0,
	0, 134, 101, 97, 112, 0, 90, 91, 92, 0,
	0, 0, 0, 85, 53, 0, 0, 0, 74, 75,
	25, 77, 78, 0, 0, 0, 54, 55, 76, 63,
	64, 65, 66, 67, 68, 69, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 104, 73, 14, 569, 32, 0, 60,
	0, 52, 0, 0, 0, 57, 56, 58, 59, 71,
	106, 312, 0, 88, 89, 70, 47, 93, 94, 36,
	0, 105, 0, 27, 0, 0, 0, 110, 26, 18,
	17, 0, 19, 0, 30, 0, 31, 0, 0, 20,
	0, 0, 0, 21, 22, 35, 37, 0, 0, 23,
	33, 0, 0, 34, 0, 0, 24, 0, 29, 86,
	87, 318, 39, 40, 41, 0, 0, 0, 0, 51,
	109, 0, 102, 98, 99, 100, 95, 96, 0, 0,
	0, 0, 0, 0, 103, 0, 0, 0, 0, 134,
	101, 97, 112, 0, 90, 91, 92, 0, 0, 0,
	0, 85, 53, 0, 0, 0, 74, 75, 25, 77,
	78, 0, 0, 0, 54, 55, 76, 63, 64, 65,
	66, 67, 68, 69, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 104, 73, 14, 311, 32, 0, 60, 0, 52,
	0, 0, 0, 57, 56, 58, 59, 71, 106, 312,
	0, 88, 89, 70, 47, 93, 94, 36, 0, 105,
	0, 27, 0, 0, 0, 110, 26, 18, 17, 0,
	19, 0, 30, 0, 31, 0, 0, 20, 0, 0,
	0, 21, 22, 35, 37, 0, 0, 23, 33, 0,
	0, 34, 0, 0, 24, 0, 29, 86, 87, 318,
	39, 40, 41, 0, 0, 0, 0, 51, 109, 0,
	102, 98, 99, 100, 95, 96, 0, 0, 0, 0,
	0, 0, 103, 0, 0, 0, 0, 134, 101, 97,
	112, 0, 90, 91, 92, 0, 0, 0, 0, 85,
	53, 0, 0, 0, 74, 75, 25, 77, 78, 0,
	0, 0, 54, 55, 76, 63, 64, 65, 66, 67,
	68, 69, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 104,
	73, 14, 0, 32, 0, 60, 0, 52, 0, 0,
	0, 57, 56, 58, 59, 71, 106, 443, 444, 454,
	455, 0, 0, 434, 0, 105, 0, 0, 0, 0,
	0, 0, 459, 460, 461, 462, 463, 464, 465, 466,
	467, 468, 469, 489, 490, 491, 492, 493, 481, 482,
	483, 0, 484, 485, 470, 471, 472, 473, 474, 475,
	476, 477, 478, 479, 480, 0, 501, 499, 500, 496,
	497, 0, 0, 488, 494, 495, 502, 503, 505, 504,
	506, 507, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 498, 509, 508, 0, 0, 445, 446,
	447, 448, 449, 450, 451, 452, 453, 456, 457, 458,
	486, 487, 437, 438, 439, 440, 441, 442, 88, 89,
	70, 47, 93, 94, 36, 0, 105, 0, 27, 0,
	0, 0, 110, 26, 18, 17, 0, 19, 0, 30,
	0, 31, 0, 0, 20, 0, 0, 0, 21, 22,
	35, 133, 0, 0, 23, 33, 0, 433, 34, 0,
	0, 24, 0, 29, 86, 87, 0, 0, 0, 0,
	0, 0, 106, 0, 51, 109, 0, 102, 98, 99,
	100, 95, 96, 0, 0, 0, 0, 0, 0, 103,
	0, 0, 0, 0, 134, 101, 97, 112, 0, 90,
	91, 92, 0, 0, 0, 0, 85, 53, 0, 0,
	0, 74, 75, 25, 0, 0, 0, 0, 0, 54,
	55, 76, 63, 64, 65, 66, 67, 68, 69, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 104, 73, 14, 0,
	32, 776, 60, 0, 52, 0, 0, 0, 57, 56,
	58, 59, 71, 106, 88, 89, 70, 47, 93, 94,
	36, 0, 105, 0, 27, 0, 0, 0, 110, 26,
	18, 17, 0, 19, 0, 30, 0, 31, 0, 0,
	20, 0, 0, 0, 21, 22, 35, 133, 0, 0,
	23, 33, 0, 0, 34, 0, 0, 24, 0, 29,
	86, 87, 0, 0, 0, 0, 0, 0, 0, 0,
	51, 109, 0, 102, 98, 99, 100, 95, 96, 0,
	0, 0, 0, 0, 0, 103, 0, 0, 0, 0,
	134, 101, 97, 112, 0, 90, 91, 92, 0, 0,
	0, 0, 85, 53, 0, 0, 0, 74, 75, 25,
	0, 0, 0, 0, 0, 54, 55, 76, 63, 64,
	65, 66, 67, 68, 69, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 104, 73, 14, 0, 32, 847, 60, 0,
	52, 0, 0, 0, 57, 56, 58, 59, 71, 106,
	88, 89, 70, 47, 93, 94, 36, 0, 105, 0,
	27, 0, 0, 0, 110, 26, 18, 17, 0, 19,
	0, 30, 0, 31, 0, 0, 20, 0, 0, 0,
	21, 22, 35, 133, 0, 0, 23, 33, 0, 0,
	34, 0, 0, 24, 0, 29, 86, 87, 0, 0,
	0, 0, 0, 0, 0, 0, 51, 109, 0, 102,
	98, 99, 100, 95, 96, 0, 0, 0, 0, 0,
	0, 103, 0, 0, 0, 0, 134, 101, 97, 112,
	0, 90, 91, 92, 0, 0, 0, 0, 85, 53,
	0, 0, 0, 74, 75, 25, 0, 0, 0, 0,
	0, 54, 55, 76, 63, 64, 65, 66, 67, 68,
	69, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 104, 73,
	14, 0, 32, 682, 60, 0, 52, 0, 0, 0,
	57, 56, 58, 59, 71, 106, 88, 89, 70, 47,
	93, 94, 36, 0, 105, 0, 27, 0, 0, 0,
	110, 26, 18, 17, 0, 19, 0, 30, 0, 31,
	0, 0, 20, 0, 0, 0, 21, 22, 35, 133,
	0, 0, 23, 33, 0, 0, 34, 0, 0, 24,
	0, 29, 86, 87, 0, 0, 0, 0, 0, 0,
	0, 0, 51, 109, 0, 102, 98, 99, 100, 95,
	96, 0, 0, 0, 0, 0, 0, 103, 0, 0,
	0, 0, 134, 101, 97, 112, 0, 90, 91, 92,
	0, 0, 0, 0, 85, 53, 0, 0, 0, 74,
	75, 25, 0, 0, 0, 0, 0, 54, 55, 76,
	63, 64, 65, 66, 67, 68, 69, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 104, 73, 14, 0, 32, 659,
	60, 0, 52, 0, 0, 0, 57, 56, 58, 59,
	71, 106, 88, 89, 70, 47, 93, 94, 36, 0,
	105, 0, 27, 0, 0, 0, 110, 26, 18, 17,
	0, 19, 0, 30, 0, 31, 0, 0, 20, 0,
	0, 0, 21, 22, 35, 133, 0, 0, 23, 33,
	0, 0, 34, 0, 0, 24, 0, 29, 86, 87,
	0, 0, 0, 0, 0, 0, 0, 0, 51, 109,
	0, 102, 98, 99, 100, 95, 96, 0, 0, 0,
	0, 0, 0, 103, 0, 0, 0, 0, 134, 101,
	97, 112, 0, 90, 91, 92, 0, 0, 0, 0,
	85, 53, 0, 0, 0, 74, 75, 25, 0, 0,
	0, 0, 0, 54, 55, 76, 63, 64, 65, 66,
	67, 68, 69, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	104, 73, 14, 0, 32, 641, 60, 0, 52, 0,
	0, 0, 57, 56, 58, 59, 71, 106, 88, 89,
	70, 47, 93, 94, 36, 0, 105, 0, 27, 0,
	0, 0, 110, 26, 18, 17, 0, 19, 0, 30,
	0, 31, 0, 0, 20, 0, 0, 0, 21, 22,
	35, 133, 0, 0, 23, 33, 0, 0, 34, 0,
	0, 24, 0, 29, 86, 87, 0, 0, 0, 0,
	0, 0, 0, 0, 51, 109, 0, 102, 98, 99,
	100, 95, 96, 0, 0, 0, 0, 0, 0, 103,
	0, 0, 0, 0, 134, 101, 97, 112, 0, 90,
	91, 92, 0, 0, 0, 0, 85, 53, 0, 0,
	0, 74, 75, 25, 0, 0, 0, 0, 0, 54,
	55, 76, 63, 64, 65, 66, 67, 68, 69, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 104, 73, 14, 0,
	32, 0, 60, 0, 52, 0, 0, 0, 57, 56,
	58, 59, 71, 106, 443, 444, 454, 455, 0, 0,
	882, 0, 0, 0, 0, 0, 0, 0, 0, 459,
	460, 461, 462, 463, 464, 465, 466, 467, 468, 469,
	489, 490, 491, 492, 493, 481, 482, 483, 0, 484,
	485, 470, 471, 472, 473, 474, 475, 476, 477, 478,
	479, 480, 0, 501, 499, 500, 496, 497, 0, 0,
	488, 494, 495, 502, 503, 505, 504, 506, 507, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	881, 509, 508, 112, 0, 445, 446, 447, 448, 449,
	450, 451, 452, 453, 456, 457, 458, 486, 487, 437,
	438, 439, 440, 441, 442, 0, 0, 0, 0, 0,
	0, 443, 444, 454, 455, 0, 0, 882, 0, 0,
	0, 0, 0, 0, 0, 0, 459, 460, 461, 462,
	463, 464, 465, 466, 467, 468, 469, 489, 490, 491,
	492, 493, 481, 482, 483, 900, 484, 485, 470, 471,
	472, 473, 474, 475, 476, 477, 478, 479, 480, 0,
	501, 499, 500, 496, 497, 0, 0, 488, 494, 495,
	502, 503, 505, 504, 506, 507, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 881, 509, 508,
	112, 0, 445, 446, 447, 448, 449, 450, 451, 452,
	453, 456, 457, 458, 486, 487, 437, 438, 439, 440,
	441, 442, 88, 89, 70, 0, 93, 94, 117, 0,
	105, 0, 0, 0, 0, 0, 110, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 133, 0, 0, 0, 0,
	0, 0, 872, 0, 0, 0, 0, 0, 86, 87,
	0, 0, 0, 0, 0, 0, 0, 0, 51, 109,
	0, 102, 98, 99, 100, 95, 96, 0, 0, 0,
	0, 0, 0, 103, 0, 0, 0, 0, 134, 101,
	97, 112, 534, 90, 91, 92, 0, 0, 0, 0,
	85, 53, 0, 0, 0, 74, 75, 139, 0, 0,
	0, 0, 0, 54, 55, 76, 63, 64, 65, 66,
	67, 68, 69, 0, 0, 0, 88, 89, 70, 0,
	93, 94, 117, 0, 105, 0, 0, 0, 0, 0,
	110, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	104, 73, 0, 0, 0, 0, 60, 530, 52, 133,
	0, 0, 57, 56, 58, 59, 71, 106, 0, 0,
	0, 0, 86, 87, 0, 0, 0, 0, 0, 0,
	0, 0, 227, 109, 0, 102, 98, 99, 100, 95,
	96, 0, 0, 0, 0, 0, 0, 103, 0, 0,
	0, 0, 134, 101, 97, 112, 0, 90, 91, 92,
	0, 0, 0, 0, 85, 53, 0, 0, 0, 74,
	75, 139, 0, 0, 0, 0, 0, 54, 55, 76,
	63, 64, 65, 66, 67, 68, 69, 0, 88, 89,
	70, 0, 93, 94, 117, 0, 105, 0, 0, 0,
	0, 0, 110, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 104, 73, 0, 0, 0, 0,
	60, 133, 52, 0, 0, 226, 57, 56, 58, 59,
	71, 106, 0, 0, 86, 87, 0, 0, 0, 0,
	0, 0, 0, 0, 51, 109, 0, 102, 98, 99,
	100, 95, 96, 0, 0, 0, 0, 0, 0, 103,
	0, 0, 0, 0, 134, 101, 97, 112, 534, 90,
	91, 92, 0, 0, 0, 0, 85, 53, 0, 0,
	0, 74, 75, 139, 0, 0, 0, 0, 0, 54,
	55, 76, 63, 64, 65, 66, 67, 68, 69, 0,
	88, 89, 70, 0, 93, 94, 117, 0, 105, 0,
	0, 0, 0, 0, 110, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 104, 73, 0, 0,
	0, 0, 60, 133, 52, 0, 0, 0, 57, 56,
	58, 59, 71, 106, 0, 0, 86, 87, 0, 0,
	0, 0, 0, 0, 0, 0, 594, 109, 0, 102,
	98, 99, 100, 95, 96, 0, 0, 0, 0, 0,
	0, 103, 0, 0, 0, 0, 134, 101, 97, 112,
	0, 90, 91, 92, 0, 0, 0, 0, 85, 53,
	0, 0, 0, 74, 75, 139, 0, 0, 0, 0,
	0, 54, 55, 76, 63, 64, 65, 66, 67, 68,
	69, 0, 88, 89, 70, 0, 93, 94, 117, 426,
	105, 0, 0, 0, 0, 0, 110, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 104, 73,
	0, 0, 0, 0, 60, 133, 52, 0, 0, 593,
	57, 56, 58, 59, 71, 106, 0, 0, 86, 87,
	0, 0, 0, 0, 0, 0, 0, 0, 51, 109,
	0, 102, 98, 99, 100, 95, 96, 0, 0, 0,
	0, 0, 0, 103, 0, 0, 0, 0, 134, 101,
	97, 112, 0, 90, 91, 92, 0, 0, 0, 0,
	85, 53, 0, 0, 0, 74, 75, 139, 0, 0,
	0, 0, 0, 54, 55, 76, 63, 64, 65, 66,
	67, 68, 69, 0, 88, 89, 70, 0, 93, 94,
	117, 0, 105, 0, 0, 0, 0, 0, 110, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	104, 73, 0, 0, 0, 0, 60, 133, 52, 0,
	0, 0, 57, 56, 58, 59, 71, 106, 0, 0,
	86, 87, 0, 0, 0, 0, 0, 0, 0, 0,
	51, 109, 0, 102, 98, 99, 100, 95, 96, 0,
	0, 0, 0, 0, 0, 103, 0, 0, 0, 0,
	134, 101, 97, 112, 0, 90, 91, 92, 0, 0,
	0, 0, 85, 53, 0, 0, 0, 74, 75, 139,
	0, 0, 0, 0, 0, 54, 55, 76, 63, 64,
	65, 66, 67, 68, 69, 0, 88, 89, 70, 0,
	93, 94, 117, 0, 105, 0, 0, 0, 0, 0,
	110, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 104, 73, 0, 0, 0, 0, 60, 133,
	52, 0, 0, 389, 57, 56, 58, 59, 71, 106,
	0, 0, 86, 87, 0, 0, 0, 0, 0, 0,
	0, 0, 51, 109, 0, 102, 98, 99, 100, 95,
	96, 0, 0, 0, 0, 0, 0, 103, 0, 0,
	0, 0, 134, 101, 97, 112, 0, 90, 91, 92,
	0, 0, 0, 0, 85, 53, 0, 0, 0, 74,
	75, 139, 0, 0, 0, 0, 0, 54, 55, 76,
	63, 64, 65, 66, 67, 68, 69, 0, 88, 89,
	70, 0, 93, 94, 117, 0, 105, 0, 0, 0,
	0, 0, 110, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 104, 73, 0, 0, 0, 365,
	60, 133, 52, 0, 0, 0, 57, 56, 58, 59,
	71, 106, 0, 0, 86, 87, 0, 0, 0, 0,
	0, 0, 0, 0, 51, 109, 0, 102, 98, 99,
	100, 95, 96, 0, 0, 0, 0, 0, 0, 103,
	0, 0, 0, 0, 134, 101, 97, 112, 0, 90,
	91, 92, 0, 0, 0, 0, 85, 53, 0, 0,
	0, 74, 75, 139, 0, 0, 0, 0, 0, 54,
	55, 76, 63, 64, 65, 66, 67, 68, 69, 0,
	0, 155, 157, 156, 179, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 104, 73, 181, 178,
	0, 0, 60, 0, 52, 0, 0, 0, 57, 56,
	58, 59, 71, 106, 153, 154, 165, 168, 169, 170,
	171, 172, 173, 175, 177, 0, 155, 157, 156, 179,
	0, 0, 0, 0, 756, 180, 159, 163, 162, 0,
	0, 0, 0, 0, 158, 0, 160, 164, 166, 167,
	174, 176, 161, 181, 178, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 153,
	154, 165, 168, 169, 170, 171, 172, 173, 175, 177,
	0, 155, 157, 156, 179, 0, 0, 709, 0, 0,
	180, 159, 163, 162, 0, 0, 0, 0, 0, 158,
	0, 160, 164, 166, 167, 174, 176, 161, 181, 178,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 153, 154, 165, 168, 169, 170,
	171, 172, 173, 175, 177, 0, 0, 0, 694, 155,
	157, 156, 179, 0, 0, 180, 159, 163, 162, 0,
	0, 0, 0, 0, 158, 0, 160, 164, 166, 167,
	174, 176, 161, 0, 0, 0, 181, 178, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 153, 154, 165, 168, 169, 170, 171, 172,
	173, 175, 177, 0, 0, 0, 692, 155, 157, 156,
	179, 0, 0, 180, 159, 163, 162, 0, 0, 0,
	0, 0, 158, 0, 160, 164, 166, 167, 174, 176,
	161, 0, 0, 0, 181, 178, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	153, 154, 165, 168, 169, 170, 171, 172, 173, 175,
	177, 0, 0, 0, 683, 155, 157, 156, 179, 0,
	0, 180, 159, 163, 162, 0, 0, 0, 0, 0,
	158, 0, 160, 164, 166, 167, 174, 176, 161, 0,
	0, 0, 181, 178, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 153, 154,
	165, 168, 169, 170, 171, 172, 173, 175, 177, 0,
	155, 157, 156, 179, 0, 0, 679, 0, 0, 180,
	159, 163, 162, 0, 0, 0, 0, 0, 158, 0,
	160, 164, 166, 167, 174, 176, 161, 181, 178, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 153, 154, 165, 168, 169, 170, 171,
	172, 173, 175, 177, 0, 155, 157, 156, 179, 0,
	0, 678, 0, 0, 180, 159, 163, 162, 0, 0,
	0, 0, 0, 158, 0, 160, 164, 166, 167, 174,
	176, 161, 181, 178, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 153, 154,
	165, 168, 169, 170, 171, 172, 173, 175, 177, 0,
	0, 0, 624, 155, 157, 156, 179, 0, 0, 180,
	159, 163, 162, 0, 0, 0, 0, 0, 158, 0,
	160, 164, 166, 167, 174, 176, 161, 0, 0, 0,
	181, 178, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 153, 154, 165, 168,
	169, 170, 171, 172, 173, 175, 177, 0, 155, 157,
	156, 179, 0, 0, 623, 0, 0, 180, 159, 163,
	162, 0, 0, 0, 0, 0, 158, 0, 160, 164,
	166, 167, 174, 176, 161, 181, 178, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 153, 154, 165, 168, 169, 170, 171, 172, 173,
	175, 177, 0, 155, 157, 156, 179, 0, 0, 622,
	0, 0, 180, 159, 163, 162, 0, 0, 0, 0,
	0, 158, 0, 160, 164, 166, 167, 174, 176, 161,
	181, 178, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 153, 154, 165, 168,
	169, 170, 171, 172, 173, 175, 177, 0, 0, 0,
	605, 155, 157, 156, 179, 0, 0, 180, 159, 163,
	162, 0, 0, 0, 0, 0, 158, 0, 160, 164,
	166, 167, 174, 176, 161, 0, 0, 0, 181, 178,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 153, 154, 165, 168, 169, 170,
	171, 172, 173, 175, 177, 0, 155, 157, 156, 179,
	0, 0, 596, 0, 0, 180, 159, 163, 162, 0,
	0, 0, 0, 0, 158, 0, 160, 164, 166, 167,
	174, 176, 161, 181, 178, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 153,
	154, 165, 168, 169, 170, 171, 172, 173, 175, 177,
	567, 0, 0, 586, 155, 157, 156, 179, 0, 0,
	180, 159, 163, 162, 0, 0, 0, 0, 0, 158,
	0, 160, 164, 166, 167, 174, 176, 161, 0, 0,
	0, 181, 178, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 153, 154, 165,
	168, 169, 170, 171, 172, 173, 175, 177, 0, 155,
	157, 156, 179, 0, 0, 584, 0, 0, 180, 159,
	163, 162, 0, 0, 0, 0, 0, 158, 0, 160,
	164, 166, 167, 174, 176, 161, 181, 178, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 153, 154, 165, 168, 169, 170, 171, 172,
	173, 175, 177, 0, 155, 157, 156, 179, 0, 0,
	0, 0, 0, 180, 159, 163, 162, 0, 0, 0,
	0, 0, 158, 0, 160, 164, 166, 167, 174, 176,
	161, 181, 178, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 153, 154, 165,
	168, 169, 170, 171, 172, 173, 175, 177, 0, 155,
	157, 156, 179, 563, 0, 0, 0, 0, 180, 159,
	163, 162, 0, 0, 0, 0, 0, 158, 0, 160,
	164, 166, 167, 174, 176, 161, 181, 178, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 153, 154, 165, 168, 169, 170, 171, 172,
	173, 175, 177, 0, 155, 157, 156, 179, 0, 0,
	557, 0, 0, 180, 159, 163, 162, 0, 0, 0,
	0, 0, 158, 0, 160, 164, 166, 167, 174, 176,
	161, 181, 178, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 153, 154, 165,
	168, 169, 170, 171, 172, 173, 175, 177, 0, 155,
	157, 156, 179, 0, 0, 553, 0, 0, 180, 159,
	163, 162, 0, 0, 0, 0, 0, 158, 0, 160,
	164, 166, 167, 174, 176, 161, 181, 178, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 412, 0,
	0, 0, 153, 154, 165, 168, 169, 170, 171, 172,
	173, 175, 177, 0, 0, 0, 0, 0, 0, 0,
	417, 0, 0, 180, 159, 163, 162, 155, 157, 156,
	179, 0, 158, 0, 160, 164, 166, 167, 174, 176,
	161, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 181, 178, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	153, 154, 165, 168, 169, 170, 171, 172, 173, 175,
	177, 0, 155, 157, 156, 179, 0, 0, 0, 0,
	0, 180, 159, 163, 162, 0, 0, 0, 0, 0,
	158, 0, 160, 164, 166, 167, 174, 176, 161, 181,
	178, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 153, 154, 165, 168, 169,
	170, 171, 172, 173, 175, 177, 0, 0, 0, 0,
	373, 155, 157, 156, 179, 0, 180, 159, 163, 162,
	0, 0, 0, 0, 0, 158, 0, 160, 164, 166,
	167, 174, 176, 161, 0, 0, 0, 0, 181, 178,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 153, 154, 165, 168, 169, 170,
	171, 172, 173, 175, 177, 0, 0, 0, 0, 152,
	155, 157, 156, 179, 0, 180, 159, 163, 162, 0,
	0, 0, 0, 0, 158, 0, 160, 164, 166, 167,
	174, 176, 161, 0, 0, 0, 0, 181, 178, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 153, 154, 165, 168, 169, 170, 171,
	172, 173, 175, 177, 0, 0, 157, 156, 179, 0,
	0, 0, 0, 0, 180, 159, 163, 162, 0, 0,
	0, 0, 0, 158, 0, 160, 164, 166, 167, 174,
	176, 161, 181, 178, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 153, 154,
	165, 168, 169, 170, 171, 172, 173, 175, 177, 0,
	0, 0, 156, 179, 0, 0, 0, 0, 0, 180,
	159, 163, 162, 0, 0, 0, 0, 0, 158, 0,
	160, 164, 166, 167, 174, 176, 161, 181, 178, 428,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 153, 154, 165, 168, 169, 170, 171,
	172, 173, 175, 177, 0, 0, 0, 0, 0, 0,
	0, 179, 0, 0, 180, 159, 163, 162, 0, 0,
	0, 0, 0, 158, 0, 160, 164, 166, 167, 174,
	176, 161, 0, 0, 0, 181, 178, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 153, 154, 165, 168, 169, 170, 171, 172, 173,
	175, 177, 0, 0, 0, 0, 179, 0, 0, 0,
	0, 0, 180, 159, 163, 162, 0, 0, 0, 0,
	0, 158, 0, 160, 164, 166, 167, 174, 176, 161,
	181, 178, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 153, 154, 165, 168,
	169, 170, 171, 172, 173, 175, 177, 0, 0, 0,
	0, 179, 0, 0, 0, 0, 0, 180, 159, 163,
	162, 0, 0, 0, 0, 0, 158, 0, 160, 164,
	166, 167, 174, 176, 161, 181, 178, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 153, 154, 165, 168, 169, 170, 171, 172, 173,
	175, 177, 0, 0, 0, 179, 0, 0, 0, 0,
	0, 0, 0, 159, 163, 162, 0, 0, 0, 0,
	0, 158, 0, 160, 164, 166, 167, 174, 176, 161,
	178, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 179, 154, 165, 168, 169,
	170, 171, 172, 173, 175, 177, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 163, 162,
	178, 0, 0, 0, 0, 158, 0, 160, 164, 166,
	167, 174, 176, 161, 0, 179, 0, 165, 168, 169,
	170, 171, 172, 173, 175, 177, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 163, 162,
	178, 0, 0, 0, 0, 158, 0, 160, 164, 166,
	167, 174, 176, 161, 0, 179, 0, 165, 168, 169,
	170, 171, 172, 173, 175, 177, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 163, 162,
	178, 0, 0, 0, 0, 0, 0, 160, 164, 166,
	167, 174, 176, 161, 0, 0, 0, 165, 168, 169,
	170, 171, 172, 173, 175, 177, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 163, 162,
	443, 444, 454, 455, 0, 0, 434, 0, 164, 166,
	167, 174, 176, 161, 0, 459, 460, 461, 462, 463,
	464, 465, 466, 467, 468, 469, 489, 490, 491, 492,
	493, 481, 482, 483, 0, 484, 485, 470, 471, 472,
	473, 474, 475, 476, 477, 478, 479, 480, 0, 501,
	499, 500, 496, 497, 0, 0, 488, 494, 495, 502,
	503, 505, 504, 506, 507, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 498, 509, 508, 0,
	0, 445, 446, 447, 448, 449, 450, 451, 452, 453,
	456, 457, 458, 486, 487, 437, 438, 439, 440, 441,
	442, 443, 444, 454, 455, 0, 0, 916, 0, 0,
	0, 0, 0, 0, 0, 0, 459, 460, 461, 462,
	463, 464, 465, 466, 467, 468, 469, 489, 490, 491,
	492, 493, 481, 482, 483, 0, 484, 485, 470, 471,
	472, 473, 474, 475, 476, 477, 478, 479, 480, 0,
	501, 499, 500, 496, 497, 0, 0, 488, 494, 495,
	502, 503, 505, 504, 506, 507, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 498, 509, 508,
	0, 0, 445, 446, 447, 448, 449, 450, 451, 452,
	453, 456, 457, 458, 486, 487, 745, 746, 747, 744,
	743, 742,
}
var yyPact = [...]int{

	-1000, -1000, 1245, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	280, 510, 594, 787, -1000, -1000, -1000, 279, 4494, 273,
	272, 5644, 5644, 5644, 140, 733, 5644, -1000, 6863, 270,
	269, 268, -1000, 425, 5644, 827, 297, 62, 541, 822,
	821, 819, 501, 507, -11, -1000, -1000, 266, -1000, -1000,
	253, 263, 4972, 5644, 343, 343, 5644, 5644, 5644, 5644,
	5644, -1000, -1000, 5644, 5644, 5644, 5644, 5644, 5644, 5644,
	262, 5644, -1000, 818, 5644, 5644, 5644, -1000, -1000, -1000,
	73, -1000, 547, 540, -1000, 180, 261, 259, 5644, 5644,
	258, 5644, 5644, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 816, 802, -1000, 115, 208, 208, 245,
	-1000, 523, 781, 195, 781, 322, -1000, -1000, 358, 630,
	92, 646, 781, -1000, -1000, -1000, -1000, 85, -1000, -60,
	3299, 5644, 706, 62, 516, 5644, 5644, 354, 6922, 644,
	352, 346, 82, -1000, -1000, 70, 62, -1000, -61, -15,
	-1000, 6922, -1000, 5644, 5644, 5644, 5644, 5644, 5644, 5644,
	5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644,
	5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644, 210,
	5532, 5644, 343, 5644, 787, -1000, 6804, 344, -1000, 815,
	-1000, 813, -1000, 576, -1000, 580, 244, 4494, 237, 341,
	296, 5420, 5644, 5644, 5644, 5644, 5644, 5644, 5644, 5644,
	5644, 5644, 5644, 5644, -1000, -1000, 5644, 5644, 5644, 110,
	4972, 104, 28, -1000, -1000, 6749, 343, 230, -1000, -1000,
	73, 5644, -1000, -1000, 4972, -1000, 380, 380, 490, 380,
	6681, 380, 380, 380, 380, 380, 380, 380, -1000, 5644,
	380, 435, 722, 683, -1000, 169, 5308, 343, 7145, 7090,
	7145, 5644, 3613, 3613, 208, -1000, 530, 207, 208, -1000,
	-1000, 5644, 5644, 6922, 6922, 5644, 6922, 6922, 704, -1000,
	786, 613, 722, 5644, -1000, -1000, 4858, -1000, 4972, 805,
	523, 338, 523, -1000, -1000, 1087, -1000, 325, -16, 642,
	781, -1000, 629, 543, 801, 609, -1000, -1000, 787, 5644,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 223, 6626,
	215, -1000, 324, 23, 6922, 6571, -1000, -1000, -1000, -1000,
	140, -1000, 775, -1000, 5644, -1000, 5644, 7254, 7294, 6977,
	7145, 7032, 7334, 408, 7374, 167, 167, 167, 490, 380,
	490, 490, 368, 368, 480, 480, 480, 480, 148, 148,
	148, 148, 480, -1000, 6516, 5644, 7200, -7, -1000, -1000,
	6461, 40, 3141, -1000, -1000, -1000, 214, 576, 572, 648,
	416, -1000, 648, 5644, -1000, 5644, -1000, -1000, 7145, 5644,
	7145, 7145, 7145, 7145, 7145, 7145, 7145, 7145, 7145, 7145,
	7145, 7145, 6406, 102, 6348, 208, -1000, 5644, -1000, 189,
	-66, 4972, 5196, -1000, 4972, 6293, 100, -1000, 185, -1000,
	-1000, -1000, -1000, 282, 785, 6235, 146, 376, 5644, 98,
	208, -1000, -1000, 5644, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	208, -1000, -1000, -1000, -1000, 140, 5644, 5644, 110, 140,
	576, -12, -1000, 6922, 6180, 6125, -1000, -1000, -1000, 6067,
	-1000, -13, -1000, 6922, 5644, 179, -1000, -1000, 929, -1000,
	-1000, -1000, 528, 599, -1000, 781, 595, 779, -1000, 526,
	-1000, 6922, 177, 4338, 5644, 5644, 5644, 233, -1000, -1000,
	206, 6922, -1000, 5644, 7200, 176, 343, 792, 4182, -1000,
	204, 287, 572, -1000, 648, -1000, -1000, 410, -55, -1000,
	6012, 5957, 2983, 408, 4026, -1000, -1000, -1000, 5899, -75,
	5644, -1000, 6922, 343, 202, 174, -1000, -1000, -1000, 97,
	-1000, -1000, 680, -1000, -1000, -1000, -1000, 5644, -1000, 7145,
	-1000, -1000, 5841, -1000, -1000, 95, 5783, -1000, -1000, 572,
	173, 5644, -1000, -1000, -1000, 159, 5084, 6922, -1000, -1000,
	781, 521, -32, -1000, -1000, 781, 779, -1000, 323, -1000,
	-1000, -1000, 5728, 321, 6922, -1000, 319, 318, 287, 7200,
	315, -1000, 158, 548, 343, 198, 4972, -1000, -1000, -1000,
	661, 287, 156, -14, -1000, 72, -1000, -1000, 676, -1000,
	-1000, -1000, -1000, 406, -55, 1427, -1000, 648, 4494, 293,
	314, -1000, -1000, -1000, 5644, 7145, -1000, 4972, -75, -1000,
	-1000, 5673, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-54, -1000, 781, 374, 779, -1000, -32, -1000, 2825, 309,
	5644, 453, -1000, 837, -1000, 155, -1000, 3714, 792, -1000,
	4972, 89, 2667, -1000, 181, 396, 139, 607, 287, 503,
	-1000, -1000, 395, -1000, -1000, -1000, 765, 747, 648, 664,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 1269, -1000,
	-1000, -1000, -1000, 3457, 7145, 129, 371, 385, 370, 781,
	-54, -1000, -1000, 369, 306, -1000, 128, -1000, 5644, 213,
	421, 305, 774, 607, -1000, -1000, -1000, 126, -1000, 122,
	-1000, 304, 648, -1000, 234, 234, 170, -1000, 771, -1000,
	-1000, 1111, -17, -1000, -71, 7526, 62, -21, -1000, -1000,
	3457, -75, -1000, -1000, -1000, -1000, 367, -1000, -1000, 3870,
	342, -1000, -1000, -1000, -1000, -1000, 303, 234, 2509, 3714,
	-1000, -1000, 76, -1000, 2351, 384, 287, 383, 183, -76,
	953, -1000, -1000, 765, -1000, 5644, -20, -1000, -77, 7526,
	-1000, -1000, 4757, 672, -1000, -1000, -1000, -1000, -1000, 3457,
	-1000, 382, 302, -1000, 119, 648, -1000, -1000, -1000, -1000,
	-25, -1000, -1000, 730, 5644, -1000, -1000, 6922, -1000, 7526,
	5644, -1000, -1000, 4650, -1000, 300, 299, 605, 694, 511,
	-1000, 516, -1000, -1000, 2193, 3457, -1000, -1000, 381, -1000,
	2035, 1877, -1000, 183, -1000, 6922, -1000, -1000, 6922, 168,
	-1000, -1000, -1000, -1000, 648, 7627, 7526, 292, 1719, -1000,
	-1000, -1000, -1000, -1000, 287, -55, -1000, -1000, 7526, -1000,
	-1000, -1000, 1561, 94, -1000, -1000, 234, 291, -1000, -1000,
	-1000, 1403, -1000,
}
var yyPgo = [...]int{

	0, 1003, 1002, 51, 9, 1000, 3, 29, 16, 999,
	11, 31, 79, 78, 49, 45, 991, 21, 988, 73,
	19, 55, 987, 0, 80, 986, 985, 38, 141, 25,
	977, 36, 975, 56, 62, 972, 10, 971, 967, 962,
	961, 13, 46, 960, 958, 100, 84, 199, 957, 955,
	953, 5, 946, 83, 40, 944, 138, 43, 930, 928,
	927, 925, 924, 119, 923, 921, 920, 918, 12, 917,
	913, 44, 42, 32, 2, 15, 668, 41, 74, 909,
	908, 907, 14, 906, 904, 47, 39, 903, 18, 8,
	809, 20, 592, 902, 121, 901, 900, 898, 71, 897,
	33, 890, 889, 30, 37, 887, 886, 28, 883, 876,
	579, 873, 866, 858, 26, 856, 63, 1, 4, 855,
	17, 845, 844, 840, 7, 839, 6, 812,
}
var yyR1 = [...]int{

	0, 127, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
	4, 4, 4, 4, 4, 4, 4, 4, 4, 5,
	5, 5, 5, 5, 5, 5, 6, 6, 116, 116,
	94, 94, 10, 10, 10, 9, 9, 9, 9, 9,
	9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
	90, 90, 16, 16, 18, 18, 7, 7, 104, 104,
	103, 103, 110, 110, 17, 17, 20, 20, 19, 19,
	98, 98, 117, 117, 22, 22, 22, 22, 22, 22,
	22, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 96, 96, 95, 95, 26,
	26, 109, 109, 27, 12, 1, 1, 2, 2, 13,
	13, 125, 125, 76, 76, 14, 15, 85, 85, 87,
	87, 86, 86, 91, 91, 91, 91, 83, 83, 82,
	82, 25, 25, 80, 80, 80, 80, 107, 107, 107,
	8, 8, 84, 84, 67, 67, 65, 65, 69, 69,
	66, 66, 118, 118, 119, 119, 29, 29, 30, 30,
	75, 75, 73, 73, 73, 74, 74, 77, 77, 115,
	115, 31, 31, 102, 102, 33, 106, 106, 34, 34,
	120, 120, 35, 35, 35, 35, 124, 124, 79, 79,
	79, 108, 108, 36, 36, 37, 38, 38, 38, 38,
	40, 40, 39, 81, 81, 122, 122, 121, 121, 123,
	123, 89, 89, 89, 89, 89, 89, 105, 105, 41,
	41, 97, 97, 68, 21, 99, 99, 42, 100, 100,
	101, 101, 44, 43, 43, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
	32, 126, 3, 3, 88, 88, 111, 111, 51, 51,
	52, 52, 52, 52, 45, 45, 46, 46, 49, 49,
	93, 93, 93, 78, 78, 56, 56, 56, 50, 50,
	50, 50, 50, 50, 50, 50, 50, 50, 50, 50,
	50, 50, 50, 50, 57, 57, 57, 23, 23, 24,
	24, 55, 58, 58, 58, 59, 59, 59, 60, 60,
	60, 60, 60, 60, 28, 28, 28, 47, 47, 47,
	61, 61, 62, 62, 62, 62, 62, 62, 53, 53,
	53, 54, 54, 54, 114, 71, 71, 113, 113, 70,
	70, 70, 70, 70, 70, 92, 92, 92, 92, 63,
	63, 63, 63, 63, 63, 63, 64, 64, 64, 64,
	48, 48, 48, 48, 48, 48, 48, 112, 112, 72,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 2, 0,
	1, 3, 1, 3, 2, 1, 1, 1, 1, 1,
	1, 4, 3, 5, 4, 3, 4, 3, 4, 3,
	1, 1, 6, 7, 6, 7, 0, 1, 3, 1,
	3, 1, 3, 1, 1, 2, 1, 3, 1, 2,
	3, 1, 2, 0, 1, 1, 1, 1, 1, 1,
	4, 3, 1, 1, 5, 7, 9, 5, 3, 3,
	3, 3, 3, 3, 1, 2, 6, 7, 9, 5,
	1, 6, 3, 3, 2, 0, 9, 1, 3, 0,
	4, 1, 3, 1, 11, 0, 1, 0, 1, 9,
	8, 1, 2, 1, 1, 6, 7, 0, 2, 0,
	2, 0, 2, 1, 2, 4, 3, 1, 4, 1,
	4, 1, 4, 3, 4, 4, 5, 0, 5, 4,
	1, 1, 1, 4, 5, 6, 1, 3, 6, 7,
	3, 6, 1, 0, 1, 3, 4, 6, 0, 1,
	1, 2, 1, 1, 1, 0, 2, 2, 4, 1,
	3, 1, 2, 3, 1, 1, 3, 1, 1, 3,
	2, 0, 3, 4, 3, 10, 1, 3, 1, 2,
	3, 1, 2, 2, 2, 3, 3, 3, 4, 3,
	1, 1, 3, 1, 3, 1, 1, 0, 1, 1,
	2, 1, 1, 1, 1, 1, 1, 3, 1, 2,
	4, 3, 1, 4, 4, 3, 1, 1, 0, 1,
	3, 1, 8, 3, 2, 6, 5, 3, 4, 2,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 2, 2, 2, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 2, 2, 2, 2, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 1, 5,
	4, 3, 1, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 1, 3, 2, 1, 2, 4, 2, 11,
	12, 0, 0, 1, 0, 4, 3, 1, 1, 2,
	2, 4, 4, 2, 1, 1, 1, 1, 0, 3,
	0, 1, 1, 0, 1, 4, 3, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 3, 2,
	3, 3, 1, 1, 1, 3, 3, 1, 1, 0,
	1, 1, 1, 3, 1, 1, 3, 1, 1, 4,
	4, 4, 4, 1, 1, 1, 3, 1, 4, 2,
	3, 3, 1, 4, 4, 3, 3, 3, 1, 3,
	1, 1, 3, 1, 1, 0, 1, 3, 1, 3,
	1, 4, 2, 6, 4, 2, 2, 1, 2, 1,
	4, 3, 3, 3, 6, 3, 1, 1, 2, 1,
	5, 4, 2, 2, 4, 2, 2, 1, 3, 1,
}
var yyChk = [...]int{

	-1000, -127, -116, -9, 2, -11, -12, -13, -14, -15,
	52, 80, 45, 39, 144, -65, -66, 21, 20, 23,
	30, 34, 35, 40, 47, 99, 19, 14, -23, 49,
	25, 27, 146, 41, 44, 36, 10, 37, -125, 53,
	54, 55, -67, -69, -28, -32, -76, 7, -60, -61,
	-58, 60, 150, 93, 105, 106, 155, 154, 156, 157,
	148, -43, -48, 108, 109, 110, 111, 112, 113, 114,
	6, 158, -50, 143, 97, 98, 107, 100, 101, -47,
	-57, -52, -45, -55, -56, 92, 50, 51, 4, 5,
	85, 86, 87, 8, 9, 67, 68, 82, 64, 65,
	66, 81, 63, 75, 142, 12, 159, -10, -59, 61,
	18, -94, 83, 148, 83, -94, 144, 10, -18, -90,
	-110, -94, 83, 37, 39, -19, -20, -98, -21, 10,
	-117, 148, -11, 37, 80, 148, 148, -24, -23, 99,
	-24, -24, -102, -33, -47, -106, 37, -34, 12, -99,
	-42, -23, 146, 131, 132, 88, 90, 89, 161, 153,
	163, 169, 155, 154, 164, 133, 165, 166, 134, 135,
	136, 137, 138, 139, 167, 140, 168, 141, 116, 91,
	152, 115, 148, 148, 148, 144, -23, 10, 147, -3,
	153, 53, -76, 10, 10, 10, 94, 95, 94, 96,
	95, 162, 118, 119, 120, 121, 122, 123, 124, 125,
	126, 127, 128, 129, 105, 106, 148, 150, 144, 58,
	148, -114, -113, -71, -70, -23, 153, 60, -23, -28,
	-57, 148, -56, 99, 150, -28, -23, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -49, 148,
	-23, -93, 17, -92, -63, 12, 77, 78, -23, -23,
	-23, 150, 79, 79, -46, -44, -45, -62, 53, -10,
	-47, 148, 148, -23, -23, 148, -23, -23, 17, 76,
	-92, -92, 17, 144, -47, -77, 148, -77, 148, 83,
	-94, 149, -94, 146, 144, -116, 146, -16, -110, -94,
	83, 146, 160, 83, 29, -94, -20, 146, 160, 162,
	-22, 145, 2, -11, -12, -13, -14, -15, 52, -23,
	21, -3, -100, -101, -23, -23, 146, 146, 146, 146,
	160, 146, 160, -3, 162, 146, 160, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -23, -23, -46, -23, 147, -23, -109, -27, -28,
	-23, -98, -117, 146, 146, 10, -126, 10, -85, 56,
	-126, -87, 56, 148, -11, 148, 146, 147, -23, 153,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -23, -23, -24, -23, -54, 10, 144, -47, -114,
	151, 160, 59, -28, 148, -23, -114, 149, -24, 143,
	-63, -63, 17, 150, 58, -23, 11, -28, 59, -24,
	-53, -6, -47, 144, 10, -5, -4, 99, 100, 101,
	102, 103, 104, 4, 5, 85, 86, 87, 88, 89,
	90, 91, 92, 93, 6, 7, 94, 95, 96, 19,
	20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
	41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
	51, 35, 36, 37, 39, 40, 97, 98, 60, 30,
	31, 32, 33, 34, 61, 62, 56, 57, 80, 54,
	55, 53, 63, 64, 66, 65, 67, 68, 82, 81,
	-53, -6, -47, -78, -77, 79, 150, 144, 58, 79,
	-78, -112, -72, -23, -23, -23, 76, 76, 142, -23,
	149, -115, -31, -23, 84, -114, 10, 146, -116, 145,
	146, 146, 83, -94, -19, 83, -94, 144, 10, 83,
	-21, -23, 148, 149, 148, 146, 160, 149, -33, -34,
	-126, -23, -42, 147, -23, -7, 160, 29, 149, 145,
	-126, 148, -85, -86, 57, -10, 144, -126, -124, -10,
	-23, -23, -117, -23, 149, 151, 145, -77, -23, 149,
	162, -71, -23, 153, 60, -114, 149, 151, 149, -64,
	10, 13, 154, 12, 10, 145, 145, 150, 145, -23,
	151, -77, -23, -77, -47, -24, -23, -54, -47, -85,
	-7, 160, 149, 149, 145, -7, 160, -23, 149, 145,
	144, 83, -104, -17, -20, -90, 144, -126, 149, -84,
	-11, 147, -23, -100, -23, -80, 144, 147, 148, -23,
	149, -27, -91, -28, 153, 60, 150, -25, -11, 147,
	-96, 148, -118, -119, -29, -30, -75, -73, 152, 61,
	62, -10, -86, -126, -124, -120, 144, 160, 149, 149,
	96, -11, 147, 145, 162, -23, -28, 148, 149, 151,
	13, -23, 145, 151, 145, -86, 149, -72, 149, -31,
	-103, -20, 144, -7, 160, -20, -104, 146, -117, 149,
	146, -107, 146, -107, 146, -118, 146, 149, 59, -28,
	148, -114, -117, -26, 42, 43, -118, 149, 160, -1,
	153, -73, -126, 144, 145, -35, -122, -121, 45, -123,
	48, -89, 104, 103, 102, 99, 100, 101, -120, -10,
	-11, 147, 146, -117, -23, -114, 151, -126, -7, 160,
	-103, 145, -17, -7, 22, 146, -100, 145, 32, 33,
	-107, 31, -107, 149, -82, -11, 147, -91, -28, -114,
	151, 28, 148, 144, 149, -88, 45, -29, -2, 84,
	144, -120, -105, -41, 12, 39, 37, -124, -89, 145,
	-117, 149, 145, 144, 145, -20, -7, 145, 146, 149,
	-23, -8, 147, 146, 145, 146, 31, -88, -117, 149,
	149, 146, -95, -10, -117, -74, 147, -74, 148, 12,
	-120, 145, 146, 160, -126, 162, -97, -68, -6, -3,
	-79, 146, 144, -120, 145, -83, -11, 147, -8, -117,
	146, -74, 26, -82, 12, 161, 145, 144, -75, 144,
	-111, -51, 12, 153, 162, 145, -41, -23, 146, 160,
	162, -6, 145, -108, -36, -37, -38, -39, -40, -10,
	-6, 80, 10, 145, -117, -117, 144, 146, 149, -10,
	-117, -117, 149, 160, 12, -23, -126, -68, -23, -126,
	145, -36, 146, 146, 46, 29, 79, 24, -117, 144,
	145, 145, -51, -126, 148, -124, 10, -4, -89, -6,
	146, 145, -117, -118, -6, 145, 149, -74, -81, 146,
	144, -117, 145,
}
var yyDef = [...]int{

	79, -2, -2, 78, 85, 86, 87, 88, 89, 90,
	0, 0, 0, 0, 123, 132, 133, 0, 0, 0,
	0, 419, 419, 419, 0, 384, 0, 144, 0, 0,
	0, 0, 150, 0, 0, 0, 80, 372, 0, 0,
	0, 0, 206, 0, -2, 418, 171, 0, -2, 435,
	421, 0, 455, 0, 0, 0, 0, 0, 0, 0,
	0, 348, 352, 0, 0, 0, 0, 0, 0, 0,
	388, 0, 362, 390, 0, 365, 0, 173, 174, 428,
	413, 433, 0, 0, -2, 0, 0, 0, 0, 0,
	0, 0, 0, 398, 399, 400, 401, 402, 403, 404,
	405, 406, 407, 0, 0, 437, 0, -2, 0, 0,
	397, 82, 0, 0, 0, 0, 79, 80, 0, 0,
	0, 116, 0, 100, 101, 113, 118, 0, 121, 0,
	0, 0, 0, 372, 0, 288, 0, 0, 420, 384,
	0, 0, 0, 234, 235, 0, 372, 237, 238, 0,
	286, 287, 145, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 123, 0, 0, 154, 371,
	373, 0, 172, 177, 371, 179, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 312, 314, 0, 419, 0, 0,
	455, 0, 454, 458, 456, 460, 0, 0, 299, -2,
	0, 0, -2, 384, 455, -2, 333, 334, 335, 336,
	0, 353, 354, 355, 356, 357, 358, 359, 360, 419,
	361, 0, 391, 392, 467, 469, 0, 0, 364, 366,
	368, 419, 0, 0, 393, 294, 386, 387, 393, 385,
	442, 0, 0, 482, 483, 0, 485, 486, 0, 409,
	0, 0, 0, 0, 439, 380, 0, 383, 455, 0,
	84, 0, 83, 92, 79, 0, 95, 0, 0, 116,
	0, 97, 0, 0, 0, 116, 119, 99, 0, 0,
	122, 131, 124, 125, 126, 127, 128, 129, 0, 0,
	0, 371, 0, 289, 291, 0, 138, 139, 140, 141,
	0, 142, 0, 371, 0, 143, 0, 316, 317, 318,
	319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
	329, 330, 331, 332, -2, -2, -2, -2, -2, -2,
	-2, -2, -2, 346, 0, 0, 351, 106, 161, -2,
	0, 0, 0, 152, 153, 371, 0, 177, 181, 0,
	0, 371, 0, 0, 207, 0, 210, 123, 297, 0,
	300, 301, 302, 303, 304, 305, 306, 307, 308, 309,
	310, 311, 0, 0, 0, 436, 451, 0, 453, 0,
	396, 455, 0, -2, 455, 0, 0, -2, 0, 363,
	468, 465, 466, 0, 0, 0, 0, 422, 0, 0,
	0, -2, -2, 0, 76, 77, 69, 70, 71, 72,
	73, 74, 75, 2, 3, 4, 5, 6, 7, 8,
	9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
	19, 20, 21, 22, 23, 24, 25, 26, 27, 28,
	29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
	39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
	49, 50, 51, 52, 53, 54, 55, 56, 57, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
	0, -2, -2, 293, 394, 0, 419, 0, 0, 0,
	177, 106, 487, 489, 0, 0, 408, 411, 410, 0,
	227, 106, 229, 231, 0, 0, 81, 91, 0, 94,
	96, 98, 0, 116, 112, 0, 116, 0, 117, 0,
	120, 371, 0, 0, 0, 288, 0, 0, 233, 236,
	0, 239, 285, 0, 350, 0, 107, 0, 0, 155,
	0, -2, 181, 371, 0, 178, 241, 0, 180, 246,
	0, 0, 0, 298, 0, 429, 431, 432, 0, 0,
	0, 457, 459, 0, 0, 0, -2, 396, 389, 0,
	476, 477, 0, 479, 471, 472, 473, 0, 475, 367,
	430, 381, 0, 382, 446, 0, 0, 445, 447, 181,
	0, 107, 481, 484, 438, 0, 107, 232, 395, 93,
	0, 0, 106, 109, 114, 0, 0, 284, 0, 134,
	202, 123, 0, 0, 290, 137, 197, 197, -2, 349,
	0, 162, 0, -2, 0, 0, 455, 149, 191, 123,
	159, -2, 0, 212, 214, 165, 219, 220, 0, 222,
	223, 224, 371, 0, 182, 267, 241, 0, 0, 0,
	0, 204, 123, 452, 0, 296, -2, 455, 464, 470,
	478, 0, 449, 443, 444, 371, 480, 488, 228, 230,
	106, 111, 0, 0, 107, 115, 106, 130, 0, 0,
	288, 0, 197, 0, 197, 0, 146, 0, 0, -2,
	455, 0, 0, 151, 0, 0, 0, 374, 218, 167,
	166, 221, 0, 241, 175, 240, 0, 0, 0, -2,
	266, 269, 271, 272, 273, 274, 275, 276, 267, 247,
	205, 123, 211, -2, 295, 0, 0, 0, 0, 107,
	106, 104, 108, 0, 0, 135, 0, 193, 0, 0,
	0, 0, 0, 374, 147, 189, 123, 0, -2, 0,
	-2, 0, 0, 123, 225, 225, 0, 215, 0, 168,
	241, 267, 0, 278, 371, 0, 372, 0, 270, 176,
	-2, 463, 474, 241, 102, 110, 0, 105, 203, 0,
	0, 123, 200, 201, 194, 195, 0, 225, 0, 0,
	185, 192, 0, 157, 0, 0, 0, 0, 0, 216,
	267, 170, 242, 0, 279, 0, 0, 282, 0, 0,
	244, 248, 0, 267, 103, 136, 187, 123, 123, -2,
	196, 0, 0, 148, 0, 0, 160, 123, 226, 123,
	0, 377, 378, 0, 0, 169, 277, 371, 243, 0,
	0, 371, 249, 0, 251, 0, 0, 261, 0, 0,
	260, 57, -2, 292, 0, -2, 123, 190, 0, 158,
	0, 0, 375, 0, 379, 217, 280, 281, 371, 0,
	250, 252, 253, 254, 0, 0, 0, 0, 0, 123,
	164, 369, 376, 283, -2, 255, 256, 257, 259, 262,
	188, 370, 0, 0, 258, 156, 225, 0, 245, 263,
	123, 0, 264,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 156, 142, 3, 159, 166, 153, 3,
	148, 149, 164, 155, 160, 154, 169, 165, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 147, 146,
	167, 162, 168, 152, 158, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 150, 3, 151, 163, 3, 143, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 144, 161, 145, 157,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
	22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
	32, 33, 34, 35, 36, 37, 38, 39, 40, 41,
	42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
	52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
	62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
	72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
	82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
	92, 93, 94, 95, 96, 97, 98, 99, 100, 101,
	102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
	112, 113, 114, 115, 116, 117, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129, 130, 131,
	132, 133, 134, 135, 136, 137, 138, 139, 140, 141,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = true
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:302
		{
			yylex.(*Parser).rootNode = node.NewRoot(yyDollar[1].list)

			// save position
			yylex.(*Parser).rootNode.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).setFreeFloating(yylex.(*Parser).rootNode, freefloating.End, yylex.(*Parser).currentToken.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:315
		{
			yyVAL.token = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:316
		{
			yyVAL.token = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:317
		{
			yyVAL.token = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:318
		{
			yyVAL.token = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:319
		{
			yyVAL.token = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:320
		{
			yyVAL.token = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:321
		{
			yyVAL.token = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:326
		{
			yyVAL.token = yyDollar[1].token
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:329
		{
			yyVAL.token = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:334
		{
			yyVAL.token = yyDollar[1].token
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:338
		{
			yyVAL.token = yyDollar[1].token
		}
	case 78:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:345
		{
			if inlineHtmlNode, ok := yyDollar[2].node.(*stmt.InlineHtml); ok && len(yyDollar[1].list) > 0 {
				prevNode := lastNode(yyDollar[1].list)
				yylex.(*Parser).splitSemiColonAndPhpCloseTag(inlineHtmlNode, prevNode)
			}

			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 79:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:358
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:367
		{
			namePart := name.NewNamePart(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{namePart}

			// save position
			namePart.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(namePart, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 81:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:380
		{
			namePart := name.NewNamePart(yyDollar[3].token.Value)
			yyVAL.list = append(yyDollar[1].list, namePart)

			// save position
			namePart.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(namePart, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 82:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:397
		{
			yyVAL.node = name.NewName(yyDollar[1].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:409
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Namespace, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:422
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:437
		{
			// error
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:444
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:450
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:456
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 89:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:462
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:468
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 91:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:474
		{
			yyVAL.node = stmt.NewHaltCompiler()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.HaltCompiller, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OpenParenthesisToken, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.CloseParenthesisToken, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 92:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:490
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewNamespace(name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).MoveFreeFloating(yyDollar[2].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 93:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:507
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewNamespace(name, yyDollar[4].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).MoveFreeFloating(yyDollar[2].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[5].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 94:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:524
		{
			yyVAL.node = stmt.NewNamespace(nil, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Namespace, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 95:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:538
		{
			yyVAL.node = yyDollar[2].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.UseDeclarationList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 96:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:552
		{
			yyVAL.node = yyDollar[3].node.(*stmt.GroupUse).SetUseType(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.UseDeclarationList, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 97:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:566
		{
			yyVAL.node = stmt.NewUseList(nil, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.UseDeclarationList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 98:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:580
		{
			yyVAL.node = stmt.NewUseList(yyDollar[2].node, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.UseDeclarationList, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 99:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:594
		{
			yyVAL.node = stmt.NewConstList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:611
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 101:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:623
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 102:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:638
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewGroupUse(nil, name, yyDollar[4].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[6].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yyDollar[3].token.FreeFloating)
			if yyDollar[5].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, append(yyDollar[5].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[5].token), yyDollar[6].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[6].token.FreeFloating)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 103:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:659
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewGroupUse(nil, name, yyDollar[5].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[7].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.UseType, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).MoveFreeFloating(yyDollar[2].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yyDollar[4].token.FreeFloating)
			if yyDollar[6].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, append(yyDollar[6].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[6].token), yyDollar[7].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[7].token.FreeFloating)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 104:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:684
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewGroupUse(nil, name, yyDollar[4].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[6].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yyDollar[3].token.FreeFloating)
			if yyDollar[5].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, append(yyDollar[5].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[5].token), yyDollar[6].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[6].token.FreeFloating)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 105:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:705
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewGroupUse(nil, name, yyDollar[5].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[7].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Use, append(yyDollar[1].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token)...))
			yylex.(*Parser).MoveFreeFloating(yyDollar[2].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yyDollar[4].token.FreeFloating)
			if yyDollar[6].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, append(yyDollar[6].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[6].token), yyDollar[7].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[7].token.FreeFloating)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 106:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:730
		{
			yyVAL.token = nil
		}
	case 107:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:734
		{
			yyVAL.token = yyDollar[1].token
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:741
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:750
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 110:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:759
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:768
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 112:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:777
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:786
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 114:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:795
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 115:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:801
		{
			yyVAL.node = yyDollar[2].node.(*stmt.Use).SetUseType(yyDollar[1].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 116:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:810
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], name)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 117:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:824
		{
			name := name.NewName(yyDollar[1].list)
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], name)
			yylex.(*Parser).setFreeFloating(name, freefloating.End, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(alias, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 118:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:845
		{
			yyVAL.node = yyDollar[1].node

			// save coments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node.(*stmt.Use).Use, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 119:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:854
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Slash, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:870
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 121:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:879
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 122:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:888
		{
			if inlineHtmlNode, ok := yyDollar[2].node.(*stmt.InlineHtml); ok && len(yyDollar[1].list) > 0 {
				prevNode := lastNode(yyDollar[1].list)
				yylex.(*Parser).splitSemiColonAndPhpCloseTag(inlineHtmlNode, prevNode)
			}

			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 123:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:901
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 124:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:910
		{
			// error
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 125:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:917
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:923
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:929
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 128:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:935
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 129:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:941
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 130:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:947
		{
			yyVAL.node = stmt.NewHaltCompiler()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.HaltCompiller, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OpenParenthesisToken, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.CloseParenthesisToken, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 131:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:965
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 132:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:978
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 133:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:984
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 134:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:990
		{
			switch n := yyDollar[5].node.(type) {
			case *stmt.While:
				n.Cond = yyDollar[3].node
			case *stmt.AltWhile:
				n.Cond = yyDollar[3].node
			}

			yyVAL.node = yyDollar[5].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.While, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 135:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:1011
		{
			yyVAL.node = stmt.NewDo(yyDollar[2].node, yyDollar[5].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[7].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.While, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[7].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[7].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 136:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php7/php7.y:1028
		{
			switch n := yyDollar[9].node.(type) {
			case *stmt.For:
				n.Init = yyDollar[3].list
				n.Cond = yyDollar[5].list
				n.Loop = yyDollar[7].list
			case *stmt.AltFor:
				n.Init = yyDollar[3].list
				n.Cond = yyDollar[5].list
				n.Loop = yyDollar[7].list
			}

			yyVAL.node = yyDollar[9].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[9].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.For, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.InitExpr, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.CondExpr, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.IncExpr, yyDollar[8].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 137:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:1055
		{
			switch n := yyDollar[5].node.(type) {
			case *stmt.Switch:
				n.Cond = yyDollar[3].node
			case *stmt.AltSwitch:
				n.Cond = yyDollar[3].node
			default:
				panic("unexpected node type")
			}

			yyVAL.node = yyDollar[5].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Switch, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 138:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1078
		{
			yyVAL.node = stmt.NewBreak(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 139:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1092
		{
			yyVAL.node = stmt.NewContinue(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1106
		{
			yyVAL.node = stmt.NewReturn(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 141:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1120
		{
			yyVAL.node = stmt.NewGlobal(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 142:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1134
		{
			yyVAL.node = stmt.NewStatic(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 143:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1148
		{
			yyVAL.node = stmt.NewEcho(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Echo, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 144:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1163
		{
			yyVAL.node = stmt.NewInlineHtml(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 145:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1175
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 146:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:1189
		{
			yyVAL.node = stmt.NewUnset(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Unset, yyDollar[2].token.FreeFloating)
			if yyDollar[4].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, append(yyDollar[4].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token), yyDollar[5].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, yyDollar[5].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.CloseParenthesisToken, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[6].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 147:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:1209
		{
			switch n := yyDollar[7].node.(type) {
			case *stmt.Foreach:
				n.Expr = yyDollar[3].node
				n.Variable = yyDollar[5].node
			case *stmt.AltForeach:
				n.Expr = yyDollar[3].node
				n.Variable = yyDollar[5].node
			}

			yyVAL.node = yyDollar[7].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[7].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Foreach, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[6].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 148:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php7/php7.y:1234
		{
			switch n := yyDollar[9].node.(type) {
			case *stmt.Foreach:
				n.Expr = yyDollar[3].node
				n.Key = yyDollar[5].node
				n.Variable = yyDollar[7].node
			case *stmt.AltForeach:
				n.Expr = yyDollar[3].node
				n.Key = yyDollar[5].node
				n.Variable = yyDollar[7].node
			}

			yyVAL.node = yyDollar[9].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[9].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Foreach, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Key, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[8].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 149:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:1261
		{
			yyVAL.node = yyDollar[5].node
			yyVAL.node.(*stmt.Declare).Consts = yyDollar[3].list

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Declare, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ConstList, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 150:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1276
		{
			yyVAL.node = stmt.NewNop()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 151:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:1289
		{
			if yyDollar[6].node == nil {
				yyVAL.node = stmt.NewTry(yyDollar[3].list, yyDollar[5].list, yyDollar[6].node)
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[5].list))
			} else {
				yyVAL.node = stmt.NewTry(yyDollar[3].list, yyDollar[5].list, yyDollar[6].node)
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))
			}

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Try, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1306
		{
			yyVAL.node = stmt.NewThrow(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 153:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1320
		{
			label := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewGoto(label)

			// save position
			label.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(label, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Label, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 154:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1337
		{
			label := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewLabel(label)

			// save position
			label.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Label, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 155:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1354
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 156:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php7/php7.y:1360
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[5].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			catch := stmt.NewCatch(yyDollar[4].list, variable, yyDollar[8].list)
			yyVAL.list = append(yyDollar[1].list, catch)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[5].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[5].token))
			catch.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[2].token, yyDollar[9].token))

			// save comments
			yylex.(*Parser).setFreeFloating(catch, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(catch, freefloating.Catch, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(variable, freefloating.Start, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(catch, freefloating.Var, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(catch, freefloating.Cond, yyDollar[7].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(catch, freefloating.Stmts, yyDollar[9].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1385
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 158:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1391
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 159:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1403
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 160:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1409
		{
			yyVAL.node = stmt.NewFinally(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Finally, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1426
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 162:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1432
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 163:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1444
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 164:
		yyDollar = yyS[yypt-11 : yypt+1]
		//line php7/php7.y:1453
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewFunction(name, yyDollar[2].token != nil, yyDollar[6].list, yyDollar[8].node, yyDollar[10].list, yyDollar[4].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[11].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			if yyDollar[2].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[2].token.FreeFloating)
				yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[3].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[3].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ParamList, yyDollar[7].token.FreeFloating)
			if yyDollar[8].node != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Params, (*yyDollar[8].node.GetFreeFloating())[freefloating.Colon])
				delete((*yyDollar[8].node.GetFreeFloating()), freefloating.Colon)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ReturnType, yyDollar[9].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[11].token.FreeFloating)

			// normalize
			if yyDollar[8].node == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Params, (*yyVAL.node.GetFreeFloating())[freefloating.ReturnType])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.ReturnType)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 165:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1489
		{
			yyVAL.token = nil
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1493
		{
			yyVAL.token = yyDollar[1].token
		}
	case 167:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1500
		{
			yyVAL.token = nil
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1504
		{
			yyVAL.token = yyDollar[1].token
		}
	case 169:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php7/php7.y:1511
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewClass(name, yyDollar[1].list, nil, yyDollar[4].ClassExtends, yyDollar[5].ClassImplements, yyDollar[8].list, yyDollar[6].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewOptionalListTokensPosition(yyDollar[1].list, yyDollar[2].token, yyDollar[9].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ModifierList, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[7].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[9].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 170:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php7/php7.y:1529
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewClass(name, nil, nil, yyDollar[3].ClassExtends, yyDollar[4].ClassImplements, yyDollar[7].list, yyDollar[5].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[8].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1549
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 172:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1555
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1564
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 174:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1576
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 175:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:1591
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewTrait(name, yyDollar[5].list, yyDollar[3].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[6].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 176:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:1611
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewInterface(name, yyDollar[3].InterfaceExtends, yyDollar[6].list, yyDollar[4].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[7].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(name, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[7].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 177:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1631
		{
			yyVAL.ClassExtends = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 178:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1637
		{
			yyVAL.ClassExtends = stmt.NewClassExtends(yyDollar[2].node)

			// save position
			yyVAL.ClassExtends.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.ClassExtends, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 179:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1652
		{
			yyVAL.InterfaceExtends = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 180:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1658
		{
			yyVAL.InterfaceExtends = stmt.NewInterfaceExtends(yyDollar[2].list)

			// save position
			yyVAL.InterfaceExtends.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.InterfaceExtends, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 181:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1673
		{
			yyVAL.ClassImplements = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 182:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1679
		{
			yyVAL.ClassImplements = stmt.NewClassImplements(yyDollar[2].list)

			// save position
			yyVAL.ClassImplements.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.ClassImplements, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 183:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1694
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 184:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:1700
		{
			yyVAL.node = expr.NewReference(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 185:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1712
		{
			yyVAL.node = expr.NewList(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.List, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArrayPairList, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 186:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1726
		{
			yyVAL.node = expr.NewShortList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save commentsc
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArrayPairList, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1742
		{
			yyVAL.node = stmt.NewFor(nil, nil, nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 188:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1751
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltFor(nil, nil, nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1771
		{
			yyVAL.node = stmt.NewForeach(nil, nil, nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 190:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1780
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltForeach(nil, nil, nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 191:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1800
		{
			yyVAL.node = stmt.NewDeclare(nil, yyDollar[1].node, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1809
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewDeclare(nil, stmtList, true)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 193:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:1829
		{
			caseList := stmt.NewCaseList(yyDollar[2].list)
			yyVAL.node = stmt.NewSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(caseList, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListEnd, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 194:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1844
		{
			caseList := stmt.NewCaseList(yyDollar[3].list)
			yyVAL.node = stmt.NewSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(caseList, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListStart, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListEnd, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 195:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1860
		{
			caseList := stmt.NewCaseList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListEnd, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 196:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:1877
		{

			caseList := stmt.NewCaseList(yyDollar[3].list)
			yyVAL.node = stmt.NewAltSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListStart, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(caseList, freefloating.CaseListEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[5].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 197:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:1899
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 198:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:1905
		{
			_case := stmt.NewCase(yyDollar[3].node, yyDollar[5].list)
			yyVAL.list = append(yyDollar[1].list, _case)

			// save position
			_case.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[5].list))

			// save comments
			yylex.(*Parser).setFreeFloating(_case, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_case, freefloating.Expr, append(yyDollar[4].token.FreeFloating))
			yylex.(*Parser).setFreeFloating(_case, freefloating.CaseSeparator, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 199:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1920
		{
			_default := stmt.NewDefault(yyDollar[4].list)
			yyVAL.list = append(yyDollar[1].list, _default)

			// save position
			_default.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[4].list))

			// save comments
			yylex.(*Parser).setFreeFloating(_default, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_default, freefloating.Default, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_default, freefloating.CaseSeparator, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1938
		{
			yyVAL.token = yyDollar[1].token
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1942
		{
			yyVAL.token = yyDollar[1].token
		}
	case 202:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:1949
		{
			yyVAL.node = stmt.NewWhile(nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 203:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:1958
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltWhile(nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 204:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:1978
		{
			yyVAL.node = stmt.NewIf(yyDollar[3].node, yyDollar[5].node, nil, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.If, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 205:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:1992
		{
			_elseIf := stmt.NewElseIf(yyDollar[4].node, yyDollar[6].node)
			yyVAL.node = yyDollar[1].node.(*stmt.If).AddElseIf(_elseIf)

			// save position
			_elseIf.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[6].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[6].node))

			// save comments
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.ElseIf, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.Expr, yyDollar[5].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2011
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 207:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2017
		{
			_else := stmt.NewElse(yyDollar[3].node)
			yyVAL.node = yyDollar[1].node.(*stmt.If).SetElse(_else)

			// save position
			_else.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[3].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(_else, freefloating.Start, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 208:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:2034
		{
			stmts := stmt.NewStmtList(yyDollar[6].list)
			yyVAL.node = stmt.NewAltIf(yyDollar[3].node, stmts, nil, nil)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[6].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[6].list))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.If, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[5].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 209:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php7/php7.y:2051
		{
			stmts := stmt.NewStmtList(yyDollar[7].list)
			_elseIf := stmt.NewAltElseIf(yyDollar[4].node, stmts)
			yyVAL.node = yyDollar[1].node.(*stmt.AltIf).AddElseIf(_elseIf)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[7].list))
			_elseIf.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[7].list))

			// save comments
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.ElseIf, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.Expr, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_elseIf, freefloating.Cond, yyDollar[6].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2072
		{
			yyVAL.node = yyDollar[1].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 211:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:2086
		{
			stmts := stmt.NewStmtList(yyDollar[4].list)
			_else := stmt.NewAltElse(stmts)
			yyVAL.node = yyDollar[1].node.(*stmt.AltIf).SetElse(_else)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[4].list))
			_else.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[4].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[6].token))

			// save comments
			yylex.(*Parser).setFreeFloating(_else, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(_else, freefloating.Else, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[5].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AltEnd, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[6].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2109
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 213:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:2115
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2124
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 215:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2130
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 216:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:2142
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, nil, yyDollar[2].token != nil, yyDollar[3].token != nil)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].node != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			} else if yyDollar[2].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[2].token, yyDollar[4].token))
			} else if yyDollar[3].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[3].token, yyDollar[4].token))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			}

			// save comments
			if yyDollar[1].node != nil {
				yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			}
			if yyDollar[2].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OptionalType, yyDollar[2].token.FreeFloating)
			}
			if yyDollar[3].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, yyDollar[3].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Variadic, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)

			// normalize
			if yyDollar[3].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, (*yyVAL.node.GetFreeFloating())[freefloating.Variadic])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.Variadic)
			}
			if yyDollar[2].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OptionalType, (*yyVAL.node.GetFreeFloating())[freefloating.Ampersand])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.Ampersand)
			}
			if yyDollar[1].node == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, (*yyVAL.node.GetFreeFloating())[freefloating.OptionalType])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.OptionalType)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 217:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:2187
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, yyDollar[6].node, yyDollar[2].token != nil, yyDollar[3].token != nil)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].node != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[6].node))
			} else if yyDollar[2].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[6].node))
			} else if yyDollar[3].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[6].node))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[6].node))
			}

			// save comments
			if yyDollar[1].node != nil {
				yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			}
			if yyDollar[2].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OptionalType, yyDollar[2].token.FreeFloating)
			}
			if yyDollar[3].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, yyDollar[3].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Variadic, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[5].token.FreeFloating)

			// normalize
			if yyDollar[3].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, (*yyVAL.node.GetFreeFloating())[freefloating.Variadic])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.Variadic)
			}
			if yyDollar[2].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.OptionalType, (*yyVAL.node.GetFreeFloating())[freefloating.Ampersand])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.Ampersand)
			}
			if yyDollar[1].node == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, (*yyVAL.node.GetFreeFloating())[freefloating.OptionalType])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.OptionalType)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 218:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:2236
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2242
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 220:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2251
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 221:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2257
		{
			yyVAL.node = node.NewNullable(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 222:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2272
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 223:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2284
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 224:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2296
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 225:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:2305
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 226:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2311
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Colon, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 227:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2323
		{
			yyVAL.node = node.NewArgumentList(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArgumentList, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 228:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:2336
		{
			yyVAL.node = node.NewArgumentList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			if yyDollar[3].token != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArgumentList, append(yyDollar[3].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token), yyDollar[4].token.FreeFloating...)...))
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArgumentList, yyDollar[4].token.FreeFloating)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2356
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 230:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2362
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 231:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2374
		{
			yyVAL.node = node.NewArgument(yyDollar[1].node, false, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 232:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2386
		{
			yyVAL.node = node.NewArgument(yyDollar[2].node, true, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2401
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 234:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2410
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 235:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2419
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2428
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 237:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2437
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 238:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2446
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = stmt.NewStaticVar(variable, nil)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2463
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = stmt.NewStaticVar(variable, yyDollar[3].node)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 240:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2484
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 241:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:2490
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2499
		{
			yyVAL.node = stmt.NewPropertyList(yyDollar[1].list, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.PropertyList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 243:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:2513
		{
			yyVAL.node = stmt.NewClassConstList(yyDollar[1].list, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewOptionalListTokensPosition(yyDollar[1].list, yyDollar[2].token, yyDollar[4].token))

			// save comments
			if len(yyDollar[1].list) > 0 {
				yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], yyVAL.node)
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ModifierList, yyDollar[2].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[2].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ConstList, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2532
		{
			yyVAL.node = stmt.NewTraitUse(yyDollar[2].list, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 245:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line php7/php7.y:2544
		{
			name := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewClassMethod(name, yyDollar[1].list, yyDollar[3].token != nil, yyDollar[7].list, yyDollar[9].node, yyDollar[10].node, yyDollar[5].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].list == nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[10].node))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListNodePosition(yyDollar[1].list, yyDollar[10].node))
			}

			// save comments
			if len(yyDollar[1].list) > 0 {
				yylex.(*Parser).MoveFreeFloating(yyDollar[1].list[0], yyVAL.node)
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ModifierList, yyDollar[2].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[2].token.FreeFloating)
			}
			if yyDollar[3].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[4].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[3].token.FreeFloating)
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, yyDollar[4].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ParameterList, yyDollar[8].token.FreeFloating)
			if yyDollar[9].node != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Params, (*yyDollar[9].node.GetFreeFloating())[freefloating.Colon])
				delete((*yyDollar[9].node.GetFreeFloating()), freefloating.Colon)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 246:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2581
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2587
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 248:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2599
		{
			yyVAL.node = stmt.NewNop()

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2612
		{
			yyVAL.node = stmt.NewTraitAdaptationList(nil)

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AdaptationList, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 250:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2624
		{
			yyVAL.node = stmt.NewTraitAdaptationList(yyDollar[2].list)

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.AdaptationList, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 251:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2639
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2645
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 253:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2654
		{
			yyVAL.node = yyDollar[1].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.NameList, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 254:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2664
		{
			yyVAL.node = yyDollar[1].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Alias, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2677
		{
			yyVAL.node = stmt.NewTraitUsePrecedence(yyDollar[1].node, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeNodeListPosition(yyDollar[1].node, yyDollar[3].list))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ref, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 256:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2693
		{
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, nil, alias)

			// save position
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ref, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(alias, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2709
		{
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, nil, alias)

			// save position
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ref, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(alias, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 258:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:2725
		{
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, alias)

			// save position
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ref, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(alias, freefloating.Start, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2741
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ref, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 260:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2757
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewTraitMethodRef(nil, name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 261:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2771
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2780
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewTraitMethodRef(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(target, freefloating.Start, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 263:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2799
		{
			yyVAL.node = stmt.NewNop()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.SemiColon, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 264:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2812
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 265:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2828
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2834
		{
			modifier := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{modifier}

			// save position
			modifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(modifier, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 267:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:2850
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 268:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2856
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2865
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2871
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2880
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 272:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2892
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2904
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 274:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2916
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 275:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2928
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2940
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 277:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:2955
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:2964
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 279:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:2973
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = stmt.NewProperty(variable, nil, yyDollar[2].str)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 280:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:2990
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = stmt.NewProperty(variable, yyDollar[3].node, yyDollar[4].str)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3011
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 282:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3020
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 283:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:3029
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewConstant(name, yyDollar[3].node, yyDollar[4].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 284:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:3047
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewConstant(name, yyDollar[3].node, yyDollar[4].str)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 285:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3065
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 286:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3074
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 287:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3083
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 288:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:3092
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 289:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3098
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 290:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3107
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 291:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3116
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 292:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php7/php7.y:3125
		{
			if yyDollar[2].node != nil {
				yyVAL.node = stmt.NewClass(nil, nil, yyDollar[2].node.(*node.ArgumentList), yyDollar[3].ClassExtends, yyDollar[4].ClassImplements, yyDollar[7].list, yyDollar[5].str)
			} else {
				yyVAL.node = stmt.NewClass(nil, nil, nil, yyDollar[3].ClassExtends, yyDollar[4].ClassImplements, yyDollar[7].list, yyDollar[5].str)
			}

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[6].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[8].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 293:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3146
		{
			if yyDollar[3].node != nil {
				yyVAL.node = expr.NewNew(yyDollar[2].node, yyDollar[3].node.(*node.ArgumentList))
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			} else {
				yyVAL.node = expr.NewNew(yyDollar[2].node, nil)
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			}

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3161
		{
			yyVAL.node = expr.NewNew(yyDollar[2].node, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 295:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:3176
		{
			listNode := expr.NewList(yyDollar[3].list)
			yyVAL.node = assign.NewAssign(listNode, yyDollar[6].node)

			// save position
			listNode.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.List, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.ArrayPairList, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[5].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 296:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:3193
		{
			shortList := expr.NewShortList(yyDollar[2].list)
			yyVAL.node = assign.NewAssign(shortList, yyDollar[5].node)

			// save position
			shortList.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(shortList, freefloating.ArrayPairList, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 297:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3209
		{
			yyVAL.node = assign.NewAssign(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 298:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:3222
		{
			yyVAL.node = assign.NewReference(yyDollar[1].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Equal, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 299:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3236
		{
			yyVAL.node = expr.NewClone(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 300:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3248
		{
			yyVAL.node = assign.NewPlus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3261
		{
			yyVAL.node = assign.NewMinus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3274
		{
			yyVAL.node = assign.NewMul(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 303:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3287
		{
			yyVAL.node = assign.NewPow(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3300
		{
			yyVAL.node = assign.NewDiv(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3313
		{
			yyVAL.node = assign.NewConcat(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3326
		{
			yyVAL.node = assign.NewMod(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3339
		{
			yyVAL.node = assign.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3352
		{
			yyVAL.node = assign.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3365
		{
			yyVAL.node = assign.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 310:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3378
		{
			yyVAL.node = assign.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 311:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3391
		{
			yyVAL.node = assign.NewShiftRight(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 312:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3404
		{
			yyVAL.node = expr.NewPostInc(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 313:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3417
		{
			yyVAL.node = expr.NewPreInc(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 314:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3429
		{
			yyVAL.node = expr.NewPostDec(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 315:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3442
		{
			yyVAL.node = expr.NewPreDec(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3454
		{
			yyVAL.node = binary.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3467
		{
			yyVAL.node = binary.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3480
		{
			yyVAL.node = binary.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3493
		{
			yyVAL.node = binary.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 320:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3506
		{
			yyVAL.node = binary.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 321:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3519
		{
			yyVAL.node = binary.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 322:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3532
		{
			yyVAL.node = binary.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3545
		{
			yyVAL.node = binary.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3558
		{
			yyVAL.node = binary.NewConcat(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3571
		{
			yyVAL.node = binary.NewPlus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3584
		{
			yyVAL.node = binary.NewMinus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3597
		{
			yyVAL.node = binary.NewMul(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3610
		{
			yyVAL.node = binary.NewPow(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3623
		{
			yyVAL.node = binary.NewDiv(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3636
		{
			yyVAL.node = binary.NewMod(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3649
		{
			yyVAL.node = binary.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3662
		{
			yyVAL.node = binary.NewShiftRight(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 333:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3675
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 334:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3687
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 335:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3699
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 336:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3711
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3723
		{
			yyVAL.node = binary.NewIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 338:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3736
		{
			yyVAL.node = binary.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 339:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3749
		{
			yyVAL.node = binary.NewEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 340:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3762
		{
			yyVAL.node = binary.NewNotEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Equal, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 341:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3776
		{
			yyVAL.node = binary.NewSmaller(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3789
		{
			yyVAL.node = binary.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 343:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3802
		{
			yyVAL.node = binary.NewGreater(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 344:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3815
		{
			yyVAL.node = binary.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 345:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3828
		{
			yyVAL.node = binary.NewSpaceship(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 346:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3841
		{
			yyVAL.node = expr.NewInstanceOf(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 347:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3854
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, append(yyDollar[1].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token), (*yyVAL.node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append((*yyVAL.node.GetFreeFloating())[freefloating.End], append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 348:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3864
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 349:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:3870
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, yyDollar[3].node, yyDollar[5].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.True, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 350:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:3884
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, nil, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cond, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.True, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 351:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:3898
		{
			yyVAL.node = binary.NewCoalesce(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:3911
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 353:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3917
		{
			yyVAL.node = cast.NewInt(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 354:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3930
		{
			yyVAL.node = cast.NewDouble(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3943
		{
			yyVAL.node = cast.NewString(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 356:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3956
		{
			yyVAL.node = cast.NewArray(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 357:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3969
		{
			yyVAL.node = cast.NewObject(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 358:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3982
		{
			yyVAL.node = cast.NewBool(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 359:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:3995
		{
			yyVAL.node = cast.NewUnset(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Cast, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 360:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4008
		{
			var e *expr.Exit
			if yyDollar[2].node != nil {
				e = yyDollar[2].node.(*expr.Exit)
			} else {
				e = expr.NewExit(nil)
			}

			yyVAL.node = e

			if strings.EqualFold(yyDollar[1].token.Value, "die") {
				e.Die = true
			}

			// save position
			if yyDollar[2].node == nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			}

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 361:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4035
		{
			yyVAL.node = expr.NewErrorSuppress(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 362:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4047
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 363:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4053
		{
			yyVAL.node = expr.NewShellExec(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4065
		{
			yyVAL.node = expr.NewPrint(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 365:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4077
		{
			yyVAL.node = expr.NewYield(nil, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 366:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4089
		{
			yyVAL.node = expr.NewYield(nil, yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 367:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4101
		{
			yyVAL.node = expr.NewYield(yyDollar[2].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 368:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4114
		{
			yyVAL.node = expr.NewYieldFrom(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 369:
		yyDollar = yyS[yypt-11 : yypt+1]
		//line php7/php7.y:4126
		{
			yyVAL.node = expr.NewClosure(yyDollar[5].list, yyDollar[7].ClosureUse, yyDollar[8].node, yyDollar[10].list, false, yyDollar[2].token != nil, yyDollar[3].str)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[11].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			if yyDollar[2].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[4].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[2].token.FreeFloating)
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, yyDollar[4].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ParameterList, yyDollar[6].token.FreeFloating)
			if yyDollar[8].node != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.LexicalVars, (*yyDollar[8].node.GetFreeFloating())[freefloating.Colon])
				delete((*yyDollar[8].node.GetFreeFloating()), freefloating.Colon)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ReturnType, yyDollar[9].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[11].token.FreeFloating)

			// normalize
			if yyDollar[8].node == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.LexicalVars, (*yyVAL.node.GetFreeFloating())[freefloating.ReturnType])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.ReturnType)
			}
			if yyDollar[7].ClosureUse == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Params, (*yyVAL.node.GetFreeFloating())[freefloating.LexicalVarList])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.LexicalVarList)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 370:
		yyDollar = yyS[yypt-12 : yypt+1]
		//line php7/php7.y:4158
		{
			yyVAL.node = expr.NewClosure(yyDollar[6].list, yyDollar[8].ClosureUse, yyDollar[9].node, yyDollar[11].list, true, yyDollar[3].token != nil, yyDollar[4].str)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[12].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Static, yyDollar[2].token.FreeFloating)
			if yyDollar[3].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[5].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Function, yyDollar[3].token.FreeFloating)
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Ampersand, yyDollar[5].token.FreeFloating)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ParameterList, yyDollar[7].token.FreeFloating)
			if yyDollar[9].node != nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.LexicalVars, (*yyDollar[9].node.GetFreeFloating())[freefloating.Colon])
				delete((*yyDollar[9].node.GetFreeFloating()), freefloating.Colon)
			}
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ReturnType, yyDollar[10].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Stmts, yyDollar[12].token.FreeFloating)

			// normalize
			if yyDollar[9].node == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.LexicalVars, (*yyVAL.node.GetFreeFloating())[freefloating.ReturnType])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.ReturnType)
			}
			if yyDollar[8].ClosureUse == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Params, (*yyVAL.node.GetFreeFloating())[freefloating.LexicalVarList])
				delete((*yyVAL.node.GetFreeFloating()), freefloating.LexicalVarList)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 371:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4194
		{
			yyVAL.str = yylex.(*Parser).Lexer.GetPhpDocComment()
			yylex.(*Parser).Lexer.SetPhpDocComment("")

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 372:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4204
		{
			yyVAL.token = nil
		}
	case 373:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4208
		{
			yyVAL.token = yyDollar[1].token
		}
	case 374:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4215
		{
			yyVAL.ClosureUse = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 375:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4221
		{
			yyVAL.ClosureUse = expr.NewClosureUse(yyDollar[3].list)

			// save position
			yyVAL.ClosureUse.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.ClosureUse, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.ClosureUse, freefloating.Use, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.ClosureUse, freefloating.LexicalVarList, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 376:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4238
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 377:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4247
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 378:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4256
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(identifier)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 379:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4271
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[2].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = expr.NewReference(variable)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(variable, freefloating.Start, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).addDollarToken(variable)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 380:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4292
		{
			yyVAL.node = expr.NewFunctionCall(yyDollar[1].node, yyDollar[2].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[2].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 381:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4304
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 382:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4317
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 383:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4330
		{
			yyVAL.node = expr.NewFunctionCall(yyDollar[1].node, yyDollar[2].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[2].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 384:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4345
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 385:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4357
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 386:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4366
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 387:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4372
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 388:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4381
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 389:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4387
		{
			yyVAL.node = expr.NewExit(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Exit, append(yyDollar[1].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 390:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4403
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 391:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4409
		{
			part := scalar.NewEncapsedStringPart(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{part}

			// save position
			part.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 392:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4419
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 393:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4428
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 394:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4434
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 395:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4443
		{
			yyVAL.node = expr.NewArray(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Array, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArrayPairList, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4457
		{
			yyVAL.node = expr.NewShortArray(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.ArrayPairList, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 397:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4470
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 398:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4485
		{
			yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 399:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4497
		{
			yyVAL.node = scalar.NewDnumber(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4509
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 401:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4521
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4533
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 403:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4545
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 404:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4557
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 405:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4569
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 406:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4581
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 407:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4593
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 408:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4605
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, []node.Node{encapsed})

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 409:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4619
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 410:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4631
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 411:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4643
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 412:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4655
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 413:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4661
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 414:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4670
		{
			yyVAL.node = expr.NewConstFetch(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 415:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4682
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(target, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 416:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4698
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(target, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4717
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 418:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4723
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 419:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:4732
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4738
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 421:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4747
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 422:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4756
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 423:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4762
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, append(yyDollar[1].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token), (*yyVAL.node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append((*yyVAL.node.GetFreeFloating())[freefloating.End], append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 424:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4772
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 425:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4781
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 426:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4787
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, append(yyDollar[1].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token), (*yyVAL.node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append((*yyVAL.node.GetFreeFloating())[freefloating.End], append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 427:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4797
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 428:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4806
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 429:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4812
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 430:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4826
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 431:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4840
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 432:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4854
		{
			yyVAL.node = expr.NewMethodCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 433:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4867
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 434:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4876
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 435:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4882
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 436:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4888
		{
			yyVAL.node = expr.NewPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 437:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4904
		{
			name := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 438:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4919
		{
			yyVAL.node = expr.NewVariable(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Dollar, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyDollar[3].node, freefloating.Start, append(yyDollar[2].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token), (*yyDollar[3].node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyDollar[3].node, freefloating.End, append((*yyDollar[3].node.GetFreeFloating())[freefloating.End], append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 439:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:4934
		{
			yyVAL.node = expr.NewVariable(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Dollar, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 440:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4950
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 441:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:4963
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Name, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 442:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:4979
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 443:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4985
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 444:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:4999
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 445:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5013
		{
			yyVAL.node = expr.NewPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 446:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5026
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 447:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5039
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 448:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5055
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 449:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5067
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, append(yyDollar[1].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token), (*yyVAL.node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append((*yyVAL.node.GetFreeFloating())[freefloating.End], append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 450:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5077
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5086
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 452:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5098
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, append(yyDollar[1].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token), (*yyVAL.node.GetFreeFloating())[freefloating.Start]...)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append((*yyVAL.node.GetFreeFloating())[freefloating.End], append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 453:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5108
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 454:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5117
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 455:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php7/php7.y:5126
		{
			yyVAL.node = expr.NewArrayItem(nil, nil)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 456:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5132
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 457:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5141
		{
			if len(yyDollar[1].list) == 0 {
				yyDollar[1].list = []node.Node{expr.NewArrayItem(nil, nil)}
			}

			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 458:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5154
		{
			if yyDollar[1].node.(*expr.ArrayItem).Key == nil && yyDollar[1].node.(*expr.ArrayItem).Val == nil {
				yyVAL.list = []node.Node{}
			} else {
				yyVAL.list = []node.Node{yyDollar[1].node}
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 459:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5167
		{
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 460:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5180
		{
			yyVAL.node = expr.NewArrayItem(nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 461:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:5192
		{
			reference := expr.NewReference(yyDollar[4].node)
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, reference)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[4].node))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(reference, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 462:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5208
		{
			reference := expr.NewReference(yyDollar[2].node)
			yyVAL.node = expr.NewArrayItem(nil, reference)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 463:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:5222
		{
			// TODO: Cannot use list() as standalone expression
			listNode := expr.NewList(yyDollar[5].list)
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, listNode)

			// save position
			listNode.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[3].token, yyDollar[6].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[6].token))

			// save comments
			yylex.(*Parser).MoveFreeFloating(yyDollar[1].node, yyVAL.node)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.Start, yyDollar[3].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.List, yyDollar[4].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.ArrayPairList, yyDollar[6].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 464:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:5241
		{
			// TODO: Cannot use list() as standalone expression
			listNode := expr.NewList(yyDollar[3].list)
			yyVAL.node = expr.NewArrayItem(nil, listNode)

			// save position
			listNode.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.List, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(listNode, freefloating.ArrayPairList, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 465:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5261
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 466:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5267
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yyVAL.list = append(yyDollar[1].list, encapsed)

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(encapsed, freefloating.Start, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 467:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5280
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 468:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5286
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{encapsed, yyDollar[2].node}

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(encapsed, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 469:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5302
		{
			name := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 470:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:5317
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[3].node)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[2].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[2].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[4].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 471:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5335
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			fetch := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewPropertyFetch(variable, fetch)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).addDollarToken(variable)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(fetch, freefloating.Start, yyDollar[3].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 472:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5355
		{
			variable := expr.NewVariable(yyDollar[2].node)

			yyVAL.node = variable

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 473:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5370
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			variable := expr.NewVariable(name)

			yyVAL.node = variable

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 474:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php7/php7.y:5387
		{
			identifier := node.NewIdentifier(yyDollar[2].token.Value)
			variable := expr.NewVariable(identifier)
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[4].node)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Var, append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, append(yyDollar[5].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[5].token)...))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append(yyDollar[6].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[6].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 475:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5406
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yylex.(*Parser).GetFreeFloatingToken(yyDollar[1].token))
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.End, append(yyDollar[3].token.FreeFloating, yylex.(*Parser).GetFreeFloatingToken(yyDollar[3].token)...))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 476:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5419
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 477:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5431
		{
			// TODO: add option to handle 64 bit integer
			if _, err := strconv.Atoi(yyDollar[1].token.Value); err == nil {
				yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)
			} else {
				yyVAL.node = scalar.NewString(yyDollar[1].token.Value)
			}

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 478:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5448
		{
			var lnumber *scalar.Lnumber
			// TODO: add option to handle 64 bit integer
			_, err := strconv.Atoi(yyDollar[2].token.Value)
			isInt := err == nil

			if isInt {
				lnumber = scalar.NewLnumber(yyDollar[2].token.Value)
				yyVAL.node = expr.NewUnaryMinus(lnumber)
			} else {
				yyDollar[2].token.Value = "-" + yyDollar[2].token.Value
				yyVAL.node = scalar.NewString(yyDollar[2].token.Value)
			}

			// save position
			if isInt {
				lnumber.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			}
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 479:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5474
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(identifier)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).addDollarToken(yyVAL.node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 480:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php7/php7.y:5492
		{
			yyVAL.node = expr.NewIsset(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Isset, yyDollar[2].token.FreeFloating)
			if yyDollar[4].token == nil {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, yyDollar[5].token.FreeFloating)
			} else {
				yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.VarList, append(yyDollar[4].token.FreeFloating, append(yylex.(*Parser).GetFreeFloatingToken(yyDollar[4].token), yyDollar[5].token.FreeFloating...)...))
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 481:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:5510
		{
			yyVAL.node = expr.NewEmpty(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Empty, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 482:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5524
		{
			yyVAL.node = expr.NewInclude(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 483:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5536
		{
			yyVAL.node = expr.NewIncludeOnce(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 484:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php7/php7.y:5548
		{
			yyVAL.node = expr.NewEval(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Eval, yyDollar[2].token.FreeFloating)
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Expr, yyDollar[4].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 485:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5562
		{
			yyVAL.node = expr.NewRequire(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 486:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php7/php7.y:5574
		{
			yyVAL.node = expr.NewRequireOnce(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			yylex.(*Parser).setFreeFloating(yyVAL.node, freefloating.Start, yyDollar[1].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 487:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5589
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 488:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php7/php7.y:5595
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			yylex.(*Parser).setFreeFloating(lastNode(yyDollar[1].list), freefloating.End, yyDollar[2].token.FreeFloating)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 489:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php7/php7.y:5607
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	}
	goto yystack /* stack new state and value */
}
